const e={display_name:"Gürültü Ekle",inputs:{latent_image:{name:"gizli_görüntü"},model:{name:"model"},noise:{name:"gürültü"},sigmas:{name:"sigmalar"}}},a={display_name:"AdımlarınıHizalaZamanlayıcı",inputs:{denoise:{name:"gürültü_azaltma"},model_type:{name:"model_türü"},steps:{name:"adımlar"}}},n={display_name:"Temel Rehber",inputs:{conditioning:{name:"koşullandırma"},model:{name:"model"}}},i={display_name:"Temel Zamanlayıcı",inputs:{denoise:{name:"gürültü_azaltma"},model:{name:"model"},scheduler:{name:"zamanlayıcı"},steps:{name:"adımlar"}}},l={display_name:"BetaÖrneklemeZamanlayıcısı",inputs:{alpha:{name:"alfa"},beta:{name:"beta"},model:{name:"model"},steps:{name:"adımlar"}}},t={display_name:"CFG Rehberi",inputs:{cfg:{name:"cfg"},model:{name:"model"},negative:{name:"negatif"},positive:{name:"pozitif"}}},o={display_name:"CFGSıfırYıldız",inputs:{model:{name:"model"}},outputs:{0:{name:"yamalı_model"}}},m={display_name:"CLIP Dikkat Çarpımı",inputs:{clip:{name:"clip"},k:{name:"k"},out:{name:"çıktı"},q:{name:"q"},v:{name:"v"}}},r={description:`[Tarifler]

stable_diffusion: clip-l
stable_cascade: clip-g
sd3: t5 xxl/ clip-g / clip-l
stable_audio: t5 base
mochi: t5 xxl
cosmos: eski t5 xxl
lumina2: gemma 2 2B
wan: umt5 xxl
 hidream: llama-3.1 (Önerilir) veya t5`,display_name:"CLIP Yükle",inputs:{clip_name:{name:"clip_adı"},device:{name:"cihaz"},type:{name:"tür"}}},s={display_name:"CLIP Birleştirme Ekle",inputs:{clip1:{name:"clip1"},clip2:{name:"clip2"}}},_={display_name:"Basit CLIP Birleştirme",inputs:{clip1:{name:"clip1"},clip2:{name:"clip2"},ratio:{name:"oran"}}},k={display_name:"CLIP Birleştirme Çıkar",inputs:{clip1:{name:"clip1"},clip2:{name:"clip2"},multiplier:{name:"çarpan"}}},d={display_name:"CLIP Kaydet",inputs:{clip:{name:"clip"},filename_prefix:{name:"dosyaadı_öneki"}}},p={display_name:"CLIP Son Katmanı Ayarla",inputs:{clip:{name:"clip"},stop_at_clip_layer:{name:"clip_katmanında_dur"}}},u={description:"Bir metin istemini bir CLIP modeli kullanarak, belirli görüntülerin oluşturulmasına yönelik difüzyon modelini yönlendirmek için kullanılabilecek bir gömme içine kodlar.",display_name:"CLIP Metin Kodlama (İstem)",inputs:{clip:{name:"clip",tooltip:"Metni kodlamak için kullanılan CLIP modeli."},text:{name:"metin",tooltip:"Kodlanacak metin."}},outputs:{0:{tooltip:"Difüzyon modelini yönlendirmek için kullanılan gömülü metni içeren bir koşullandırma."}}},c={display_name:"CLIPMetinKodlamaControlnet",inputs:{clip:{name:"clip"},conditioning:{name:"koşullandırma"},text:{name:"metin"}}},g={display_name:"CLIPMetinKodlamaFlux",inputs:{clip:{name:"clip"},clip_l:{name:"clip_l"},guidance:{name:"rehberlik"},t5xxl:{name:"t5xxl"}}},b={display_name:"CLIPMetinKodlamaHiDream",inputs:{clip:{name:"clip"},clip_g:{name:"clip_g"},clip_l:{name:"clip_l"},llama:{name:"llama"},t5xxl:{name:"t5xxl"}}},y={display_name:"CLIPMetinKodlamaHunyuanDiT",inputs:{bert:{name:"bert"},clip:{name:"clip"},mt5xl:{name:"mt5xl"}}},f={description:"Bir sistem istemini ve bir kullanıcı istemini bir CLIP modeli kullanarak, belirli görüntülerin oluşturulmasına yönelik difüzyon modelini yönlendirmek için kullanılabilecek bir gömme içine kodlar.",display_name:"Lumina2 için CLIP Metin Kodlama",inputs:{clip:{name:"clip",tooltip:"Metni kodlamak için kullanılan CLIP modeli."},system_prompt:{name:"sistem_istemi",tooltip:"Lumina2 iki tür sistem istemi sağlar: Üstün: Metinsel istemlere veya kullanıcı istemlerine dayalı olarak üstün derecede görüntü-metin hizalamasına sahip üstün görüntüler oluşturmak için tasarlanmış bir asistansınız. Hizalama: Metinsel istemlere dayalı olarak en yüksek derecede görüntü-metin hizalamasına sahip yüksek kaliteli görüntüler oluşturmak için tasarlanmış bir asistansınız."},user_prompt:{name:"kullanıcı_istemi",tooltip:"Kodlanacak metin."}},outputs:{0:{tooltip:"Difüzyon modelini yönlendirmek için kullanılan gömülü metni içeren bir koşullandırma."}}},h={description:"Metni kodlar ve PixArt Alpha için çözünürlük koşullandırmasını ayarlar. PixArt Sigma için geçerli değildir.",display_name:"CLIPMetinKodlamaPixArtAlpha",inputs:{clip:{name:"clip"},height:{name:"yükseklik"},text:{name:"metin"},width:{name:"genişlik"}}},z={display_name:"CLIPMetinKodlamaSD3",inputs:{clip:{name:"clip"},clip_g:{name:"clip_g"},clip_l:{name:"clip_l"},empty_padding:{name:"boş_dolgu"},t5xxl:{name:"t5xxl"}}},v={display_name:"CLIPMetinKodlamaSDXL",inputs:{clip:{name:"clip"},crop_h:{name:"kırpma_y"},crop_w:{name:"kırpma_g"},height:{name:"yükseklik"},target_height:{name:"hedef_yükseklik"},target_width:{name:"hedef_genişlik"},text_g:{name:"metin_g"},text_l:{name:"metin_l"},width:{name:"genişlik"}}},S={display_name:"CLIPMetinKodlamaSDXLRefiner",inputs:{ascore:{name:"askor"},clip:{name:"clip"},height:{name:"yükseklik"},text:{name:"metin"},width:{name:"genişlik"}}},L={display_name:"CLIP Görü Kodlama",inputs:{clip_vision:{name:"clip_görü"},crop:{name:"kırp"},image:{name:"görüntü"}}},C={display_name:"CLIP Görü Yükle",inputs:{clip_name:{name:"clip_adı"}}},M={display_name:"Canny",inputs:{high_threshold:{name:"yüksek_eşik"},image:{name:"görüntü"},low_threshold:{name:"düşük_eşik"}}},G={display_name:"Yapılandırmayla Kontrol Noktası Yükle (ESKİ)",inputs:{ckpt_name:{name:"ckpt_adı"},config_name:{name:"yapılandırma_adı"}}},V={description:"Bir difüzyon modeli kontrol noktası yükler, difüzyon modelleri gizli değişkenlerin gürültüsünü azaltmak için kullanılır.",display_name:"Kontrol Noktası Yükle",inputs:{ckpt_name:{name:"ckpt_adı",tooltip:"Yüklenecek kontrol noktasının (modelin) adı."}},outputs:{0:{tooltip:"Gizli değişkenlerin gürültüsünü azaltmak için kullanılan model."},1:{tooltip:"Metin istemlerini kodlamak için kullanılan CLIP modeli."},2:{tooltip:"Görüntüleri gizli uzaya ve gizli uzaydan kodlamak ve kodunu çözmek için kullanılan VAE modeli."}}},I={display_name:"Kontrol Noktasını Kaydet",inputs:{clip:{name:"clip"},filename_prefix:{name:"dosyaadı_öneki"},model:{name:"model"},vae:{name:"vae"}}},A={display_name:"Kancaları Birleştir [2]",inputs:{hooks_A:{name:"kancalar_A"},hooks_B:{name:"kancalar_B"}}},P={display_name:"Kancaları Birleştir [4]",inputs:{hooks_A:{name:"kancalar_A"},hooks_B:{name:"kancalar_B"},hooks_C:{name:"kancalar_C"},hooks_D:{name:"kancalar_D"}}},D={display_name:"Kancaları Birleştir [8]",inputs:{hooks_A:{name:"kancalar_A"},hooks_B:{name:"kancalar_B"},hooks_C:{name:"kancalar_C"},hooks_D:{name:"kancalar_D"},hooks_E:{name:"kancalar_E"},hooks_F:{name:"kancalar_F"},hooks_G:{name:"kancalar_G"},hooks_H:{name:"kancalar_H"}}},K={display_name:"KoşullandırmaOrtalaması",inputs:{conditioning_from:{name:"kaynak_koşullandırma"},conditioning_to:{name:"hedef_koşullandırma"},conditioning_to_strength:{name:"hedef_koşullandırma_gücü"}}},x={display_name:"Koşullandırma (Birleştir)",inputs:{conditioning_1:{name:"koşullandırma_1"},conditioning_2:{name:"koşullandırma_2"}}},B={display_name:"Koşullandırma (Birleştir)",inputs:{conditioning_from:{name:"kaynak_koşullandırma"},conditioning_to:{name:"hedef_koşullandırma"}}},T={display_name:"Koşullandırma (Alan Ayarla)",inputs:{conditioning:{name:"koşullandırma"},height:{name:"yükseklik"},strength:{name:"güç"},width:{name:"genişlik"},x:{name:"x"},y:{name:"y"}}},E={display_name:"Koşullandırma (Yüzde ile Alan Ayarla)",inputs:{conditioning:{name:"koşullandırma"},height:{name:"yükseklik"},strength:{name:"güç"},width:{name:"genişlik"},x:{name:"x"},y:{name:"y"}}},N={display_name:"KoşullandırmaAlanYüzdesiVideo",inputs:{conditioning:{name:"koşullandırma"},height:{name:"yükseklik"},strength:{name:"güç"},temporal:{name:"zamansal"},width:{name:"genişlik"},x:{name:"x"},y:{name:"y"},z:{name:"z"}}},R={display_name:"KoşullandırmaAlanGücüAyarla",inputs:{conditioning:{name:"koşullandırma"},strength:{name:"güç"}}},F={display_name:"Koşul Varsayılan Birleştirmeyi Ayarla",inputs:{cond:{name:"koşul"},cond_DEFAULT:{name:"koşul_VARSAYILAN"},hooks:{name:"kancalar"}}},U={display_name:"Koşullandırma (Maske Ayarla)",inputs:{conditioning:{name:"koşullandırma"},mask:{name:"maske"},set_cond_area:{name:"koşul_alanı_ayarla"},strength:{name:"güç"}}},w={display_name:"Koşul Özelliklerini Ayarla",inputs:{cond_NEW:{name:"yeni_koşul"},hooks:{name:"kancalar"},mask:{name:"maske"},set_cond_area:{name:"koşul_alanı_ayarla"},strength:{name:"güç"},timesteps:{name:"zaman_adımları"}}},O={display_name:"Koşul Özelliklerini Ayarla ve Birleştir",inputs:{cond:{name:"koşul"},cond_NEW:{name:"yeni_koşul"},hooks:{name:"kancalar"},mask:{name:"maske"},set_cond_area:{name:"koşul_alanı_ayarla"},strength:{name:"güç"},timesteps:{name:"zaman_adımları"}}},j={display_name:"KoşullandırmaZamanAdımıAralığıAyarla",inputs:{conditioning:{name:"koşullandırma"},end:{name:"bitiş"},start:{name:"başlangıç"}}},H={display_name:"KoşullandırmaKararlıSes",inputs:{negative:{name:"negatif"},positive:{name:"pozitif"},seconds_start:{name:"saniye_başlangıç"},seconds_total:{name:"saniye_toplam"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"}}},Y={display_name:"Zaman Adımları Aralığı",inputs:{end_percent:{name:"bitiş_yüzdesi"},start_percent:{name:"başlangıç_yüzdesi"}},outputs:{1:{name:"ARALIK_ÖNCESİ"},2:{name:"ARALIK_SONRASI"}}},W={display_name:"KoşullandırmaSıfırla",inputs:{conditioning:{name:"koşullandırma"}}},X={display_name:"ControlNet Uygula (ESKİ)",inputs:{conditioning:{name:"koşullandırma"},control_net:{name:"kontrol_ağı"},image:{name:"görüntü"},strength:{name:"güç"}}},Z={display_name:"ControlNet Uygula",inputs:{control_net:{name:"kontrol_ağı"},end_percent:{name:"bitiş_yüzdesi"},image:{name:"görüntü"},negative:{name:"negatif"},positive:{name:"pozitif"},start_percent:{name:"başlangıç_yüzdesi"},strength:{name:"güç"},vae:{name:"vae"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"}}},q={display_name:"VAE ile Controlnet Uygula",inputs:{control_net:{name:"kontrol_ağı"},end_percent:{name:"bitiş_yüzdesi"},image:{name:"görüntü"},negative:{name:"negatif"},positive:{name:"pozitif"},start_percent:{name:"başlangıç_yüzdesi"},strength:{name:"güç"},vae:{name:"vae"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"}}},Q={display_name:"ControlNetInpaintingAliMamaUygula",inputs:{control_net:{name:"kontrol_ağı"},end_percent:{name:"bitiş_yüzdesi"},image:{name:"görüntü"},mask:{name:"maske"},negative:{name:"negatif"},positive:{name:"pozitif"},start_percent:{name:"başlangıç_yüzdesi"},strength:{name:"güç"},vae:{name:"vae"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"}}},J={display_name:"ControlNet Modelini Yükle",inputs:{control_net_name:{name:"kontrol_ağı_adı"}}},$={display_name:"CosmosGörüntüdenVideoyaGizli",inputs:{batch_size:{name:"toplu_boyut"},end_image:{name:"bitiş_görüntüsü"},height:{name:"yükseklik"},length:{name:"uzunluk"},start_image:{name:"başlangıç_görüntüsü"},vae:{name:"vae"},width:{name:"genişlik"}}},ee={display_name:"Kanca Anahtar Karesi Oluştur",inputs:{prev_hook_kf:{name:"önceki_kanca_kf"},start_percent:{name:"başlangıç_yüzdesi"},strength_mult:{name:"güç_çarpanı"}},outputs:{0:{name:"Kanca_KF"}}},ae={display_name:"Ondalıklardan Kanca Anahtar Kareleri Oluştur",inputs:{end_percent:{name:"bitiş_yüzdesi"},floats_strength:{name:"ondalık_güç"},prev_hook_kf:{name:"önceki_kanca_kf"},print_keyframes:{name:"anahtar_kareleri_yazdır"},start_percent:{name:"başlangıç_yüzdesi"}},outputs:{0:{name:"Kanca_KF"}}},ne={display_name:"Ara Değerlenmiş Kanca Anahtar Kareleri Oluştur",inputs:{end_percent:{name:"bitiş_yüzdesi"},interpolation:{name:"enterpolasyon"},keyframes_count:{name:"anahtar_kare_sayısı"},prev_hook_kf:{name:"önceki_kanca_kf"},print_keyframes:{name:"anahtar_kareleri_yazdır"},start_percent:{name:"başlangıç_yüzdesi"},strength_end:{name:"bitiş_gücü"},strength_start:{name:"başlangıç_gücü"}},outputs:{0:{name:"Kanca_KF"}}},ie={display_name:"Kanca LoRA Oluştur",inputs:{lora_name:{name:"lora_adı"},prev_hooks:{name:"önceki_kancalar"},strength_clip:{name:"clip_gücü"},strength_model:{name:"model_gücü"}}},le={display_name:"Kanca LoRA Oluştur (Sadece Model)",inputs:{lora_name:{name:"lora_adı"},prev_hooks:{name:"önceki_kancalar"},strength_model:{name:"model_gücü"}}},te={display_name:"Modeli LoRA Olarak Kanca Oluştur",inputs:{ckpt_name:{name:"ckpt_adı"},prev_hooks:{name:"önceki_kancalar"},strength_clip:{name:"clip_gücü"},strength_model:{name:"model_gücü"}}},oe={display_name:"Modeli LoRA Olarak Kanca Oluştur (Sadece Model)",inputs:{ckpt_name:{name:"ckpt_adı"},prev_hooks:{name:"önceki_kancalar"},strength_model:{name:"model_gücü"}}},me={description:"Görüntülerden bir video oluşturun.",display_name:"Video Oluştur",inputs:{audio:{name:"ses",tooltip:"Videoya eklenecek ses."},fps:{name:"fps"},images:{name:"görüntüler",tooltip:"Video oluşturulacak görüntüler."}}},re={display_name:"Maskeyi Kırp",inputs:{height:{name:"yükseklik"},mask:{name:"maske"},width:{name:"genişlik"},x:{name:"x"},y:{name:"y"}}},se={display_name:"ControlNet Modelini Yükle (fark)",inputs:{control_net_name:{name:"kontrol_ağı_adı"},model:{name:"model"}}},_e={display_name:"Diferansiyel Difüzyon",inputs:{model:{name:"model"}}},ke={display_name:"Diffusers Yükleyici",inputs:{model_path:{name:"model_yolu"}}},de={display_name:"Gürültüyü Devre Dışı Bırak"},pe={display_name:"İkili CFG Rehberi",inputs:{cfg_cond2_negative:{name:"cfg_koşul2_negatif"},cfg_conds:{name:"cfg_koşulları"},cond1:{name:"koşul1"},cond2:{name:"koşul2"},model:{name:"model"},negative:{name:"negatif"}}},ue={description:`[Tarifler]

sdxl: clip-l, clip-g
sd3: clip-l, clip-g / clip-l, t5 / clip-g, t5
flux: clip-l, t5
hidream: t5 veya llama'dan en az biri, t5 ve llama önerilir`,display_name:"İkili CLIP Yükleyici",inputs:{clip_name1:{name:"clip_adı1"},clip_name2:{name:"clip_adı2"},device:{name:"cihaz"},type:{name:"tür"}}},ce={display_name:"BoşCosmosGizliVideo",inputs:{batch_size:{name:"toplu_boyut"},height:{name:"yükseklik"},length:{name:"uzunluk"},width:{name:"genişlik"}}},ge={display_name:"BoşHunyuanGizliVideo",inputs:{batch_size:{name:"toplu_boyut"},height:{name:"yükseklik"},length:{name:"uzunluk"},width:{name:"genişlik"}}},be={display_name:"Boş Görüntü",inputs:{batch_size:{name:"toplu_boyut"},color:{name:"renk"},height:{name:"yükseklik"},width:{name:"genişlik"}}},ye={display_name:"BoşLTXVGizliVideo",inputs:{batch_size:{name:"toplu_boyut"},height:{name:"yükseklik"},length:{name:"uzunluk"},width:{name:"genişlik"}}},fe={display_name:"Boş Gizli Ses",inputs:{batch_size:{name:"toplu_boyut",tooltip:"Toplu işlemdeki gizli görüntülerin sayısı."},seconds:{name:"saniye"}}},he={display_name:"BoşGizliHunyuan3Dv2",inputs:{batch_size:{name:"toplu_boyut",tooltip:"Toplu işlemdeki gizli görüntülerin sayısı."},resolution:{name:"çözünürlük"}}},ze={description:"Örnekleme yoluyla gürültüsü giderilecek yeni bir boş gizli görüntü grubu oluşturun.",display_name:"Boş Gizli Görüntü",inputs:{batch_size:{name:"toplu_boyut",tooltip:"Toplu işlemdeki gizli görüntülerin sayısı."},height:{name:"yükseklik",tooltip:"Gizli görüntülerin piksel cinsinden yüksekliği."},width:{name:"genişlik",tooltip:"Gizli görüntülerin piksel cinsinden genişliği."}},outputs:{0:{tooltip:"Boş gizli görüntü grubu."}}},ve={display_name:"BoşMochiGizliVideo",inputs:{batch_size:{name:"toplu_boyut"},height:{name:"yükseklik"},length:{name:"uzunluk"},width:{name:"genişlik"}}},Se={display_name:"BoşSD3GizliGörüntü",inputs:{batch_size:{name:"toplu_boyut"},height:{name:"yükseklik"},width:{name:"genişlik"}}},Le={display_name:"Üstel Zamanlayıcı",inputs:{sigma_max:{name:"sigma_maks"},sigma_min:{name:"sigma_min"},steps:{name:"adımlar"}}},Ce={display_name:"AraSigmalarıGenişlet",inputs:{end_at_sigma:{name:"sigma_bitişi"},sigmas:{name:"sigmalar"},spacing:{name:"aralık"},start_at_sigma:{name:"sigma_başlangıcı"},steps:{name:"adımlar"}}},Me={display_name:"Maskeyi Yumuşat",inputs:{bottom:{name:"alt"},left:{name:"sol"},mask:{name:"maske"},right:{name:"sağ"},top:{name:"üst"}}},Ge={display_name:"Sigmaları Çevir",inputs:{sigmas:{name:"sigmalar"}}},Ve={description:"Bu düğüm, Flux ve Flux benzeri modellerdeki rehberlik gömmesini tamamen devre dışı bırakır",display_name:"FluxRehberliğiDevreDışıBırak",inputs:{conditioning:{name:"koşullandırma"}}},Ie={display_name:"FluxRehberliği",inputs:{conditioning:{name:"koşullandırma"},guidance:{name:"rehberlik"}}},Ae={description:"İsteme göre görüntüyü dışa doğru boyar.",display_name:"Flux.1 Görüntüyü Genişlet",inputs:{bottom:{name:"alt",tooltip:"Görüntünün altında genişletilecek piksel sayısı"},control_after_generate:{name:"oluşturduktan sonra kontrol et"},guidance:{name:"rehberlik",tooltip:"Görüntü oluşturma süreci için rehberlik gücü"},image:{name:"görüntü"},left:{name:"sol",tooltip:"Görüntünün sol tarafında genişletilecek piksel sayısı"},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi"},prompt_upsampling:{name:"istem_yükseltme",tooltip:"İstem üzerinde yükseltme yapılıp yapılmayacağı. Etkinse, daha yaratıcı üretim için istemi otomatik olarak değiştirir, ancak sonuçlar belirleyici değildir (aynı tohum tam olarak aynı sonucu vermez)."},right:{name:"sağ",tooltip:"Görüntünün sağ tarafında genişletilecek piksel sayısı"},seed:{name:"tohum",tooltip:"Gürültüyü oluşturmak için kullanılan rastgele tohum."},steps:{name:"adımlar",tooltip:"Görüntü oluşturma süreci için adım sayısı"},top:{name:"üst",tooltip:"Görüntünün üstünde genişletilecek piksel sayısı"}}},Pe={description:"Maske ve isteme göre görüntüyü içe doğru boyar.",display_name:"Flux.1 Görüntüyü Doldur",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},guidance:{name:"rehberlik",tooltip:"Görüntü oluşturma süreci için rehberlik gücü"},image:{name:"görüntü"},mask:{name:"maske"},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi"},prompt_upsampling:{name:"istem_yükseltme",tooltip:"İstem üzerinde yükseltme yapılıp yapılmayacağı. Etkinse, daha yaratıcı üretim için istemi otomatik olarak değiştirir, ancak sonuçlar belirleyici değildir (aynı tohum tam olarak aynı sonucu vermez)."},seed:{name:"tohum",tooltip:"Gürültüyü oluşturmak için kullanılan rastgele tohum."},steps:{name:"adımlar",tooltip:"Görüntü oluşturma süreci için adım sayısı"}}},De={description:"İstem ve çözünürlüğe dayalı olarak api aracılığıyla Flux Pro 1.1 Ultra kullanarak görüntüler oluşturur.",display_name:"Flux 1.1 [pro] Ultra Görüntü",inputs:{aspect_ratio:{name:"en_boy_oranı",tooltip:"Görüntünün en boy oranı; 1:4 ile 4:1 arasında olmalıdır."},control_after_generate:{name:"oluşturduktan sonra kontrol et"},image_prompt:{name:"görüntü_istemi"},image_prompt_strength:{name:"görüntü_istemi_gücü",tooltip:"İstem ile görüntü istemi arasında karıştırın."},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi"},prompt_upsampling:{name:"istem_yükseltme",tooltip:"İstem üzerinde yükseltme yapılıp yapılmayacağı. Etkinse, daha yaratıcı üretim için istemi otomatik olarak değiştirir, ancak sonuçlar belirleyici değildir (aynı tohum tam olarak aynı sonucu vermez)."},raw:{name:"ham",tooltip:"Doğru olduğunda, daha az işlenmiş, daha doğal görünümlü görüntüler oluşturun."},seed:{name:"tohum",tooltip:"Gürültüyü oluşturmak için kullanılan rastgele tohum."}}},Ke={description:"Rehberliğe frekansa bağlı ölçeklendirme uygular",display_name:"FreSca",inputs:{freq_cutoff:{name:"frekans_kesme",tooltip:"Merkez etrafındaki frekans indekslerinin düşük frekanslı olarak kabul edileceği sayı"},model:{name:"model"},scale_high:{name:"yüksek_ölçek",tooltip:"Yüksek frekanslı bileşenler için ölçeklendirme faktörü"},scale_low:{name:"düşük_ölçek",tooltip:"Düşük frekanslı bileşenler için ölçeklendirme faktörü"}}},xe={display_name:"FreeU",inputs:{b1:{name:"b1"},b2:{name:"b2"},model:{name:"model"},s1:{name:"s1"},s2:{name:"s2"}}},Be={display_name:"FreeU_V2",inputs:{b1:{name:"b1"},b2:{name:"b2"},model:{name:"model"},s1:{name:"s1"},s2:{name:"s2"}}},Te={display_name:"GITSZamanlayıcı",inputs:{coeff:{name:"katsayı"},denoise:{name:"gürültü_azaltma"},steps:{name:"adımlar"}}},Ee={display_name:"GLIGENYükleyici",inputs:{gligen_name:{name:"gligen_adı"}}},Ne={display_name:"GLIGENMetinKutusuUygula",inputs:{clip:{name:"clip"},conditioning_to:{name:"hedef_koşullandırma"},gligen_textbox_model:{name:"gligen_metinkutusu_modeli"},height:{name:"yükseklik"},text:{name:"metin"},width:{name:"genişlik"},x:{name:"x"},y:{name:"y"}}},Re={description:"Bir videodan tüm bileşenleri çıkarır: kareler, ses ve kare hızı.",display_name:"Video Bileşenlerini Al",inputs:{video:{name:"video",tooltip:"Bileşenlerin çıkarılacağı video."}},outputs:{0:{name:"görüntüler"},1:{name:"ses"},2:{name:"fps"}}},Fe={display_name:"Maskeyi Büyüt",inputs:{expand:{name:"genişlet"},mask:{name:"maske"},tapered_corners:{name:"sivri_köşeler"}}},Ue={display_name:"Hunyuan3Dv2Koşullandırma",inputs:{clip_vision_output:{name:"clip_görü_çıktısı"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"}}},we={display_name:"Hunyuan3Dv2ÇokluGörünümKoşullandırma",inputs:{back:{name:"arka"},front:{name:"ön"},left:{name:"sol"},right:{name:"sağ"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"}}},Oe={display_name:"HunyuanGörüntüdenVideoya",inputs:{batch_size:{name:"toplu_boyut"},guidance_type:{name:"rehberlik_türü"},height:{name:"yükseklik"},length:{name:"uzunluk"},positive:{name:"pozitif"},start_image:{name:"başlangıç_görüntüsü"},vae:{name:"vae"},width:{name:"genişlik"}},outputs:{0:{name:"pozitif"},1:{name:"gizli"}}},je={display_name:"HiperDöşeme",inputs:{max_depth:{name:"maks_derinlik"},model:{name:"model"},scale_depth:{name:"ölçek_derinliği"},swap_size:{name:"değiştirme_boyutu"},tile_size:{name:"döşeme_boyutu"}}},He={display_name:"HiperAğYükleyici",inputs:{hypernetwork_name:{name:"hiperağ_adı"},model:{name:"model"},strength:{name:"güç"}}},Ye={description:`Ideogram V1 modelini kullanarak eşzamanlı olarak görüntüler oluşturur.

Görüntü bağlantıları sınırlı bir süre için mevcuttur; görüntüyü saklamak isterseniz indirmeniz gerekir.`,display_name:"Ideogram V1",inputs:{aspect_ratio:{name:"en_boy_oranı",tooltip:"Görüntü oluşturma için en boy oranı."},control_after_generate:{name:"oluşturduktan sonra kontrol et"},magic_prompt_option:{name:"sihirli_istem_seçeneği",tooltip:"Üretimde MagicPrompt'un kullanılıp kullanılmayacağını belirleyin"},negative_prompt:{name:"negatif_istem",tooltip:"Görüntüden hariç tutulacakların açıklaması"},num_images:{name:"görüntü_sayısı"},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi"},seed:{name:"tohum"},turbo:{name:"turbo",tooltip:"Turbo modunun kullanılıp kullanılmayacağı (daha hızlı üretim, potansiyel olarak daha düşük kalite)"}}},We={description:`Ideogram V2 modelini kullanarak eşzamanlı olarak görüntüler oluşturur.

Görüntü bağlantıları sınırlı bir süre için mevcuttur; görüntüyü saklamak isterseniz indirmeniz gerekir.`,display_name:"Ideogram V2",inputs:{aspect_ratio:{name:"en_boy_oranı",tooltip:"Görüntü oluşturma için en boy oranı. Çözünürlük AUTO olarak ayarlanmadıysa yoksayılır."},control_after_generate:{name:"oluşturduktan sonra kontrol et"},magic_prompt_option:{name:"sihirli_istem_seçeneği",tooltip:"Üretimde MagicPrompt'un kullanılıp kullanılmayacağını belirleyin"},negative_prompt:{name:"negatif_istem",tooltip:"Görüntüden hariç tutulacakların açıklaması"},num_images:{name:"görüntü_sayısı"},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi"},resolution:{name:"çözünürlük",tooltip:"Görüntü oluşturma için çözünürlük. AUTO olarak ayarlanmadıysa, bu en_boy_oranı ayarını geçersiz kılar."},seed:{name:"tohum"},style_type:{name:"stil_türü",tooltip:"Üretim için stil türü (yalnızca V2)"},turbo:{name:"turbo",tooltip:"Turbo modunun kullanılıp kullanılmayacağı (daha hızlı üretim, potansiyel olarak daha düşük kalite)"}}},Xe={description:`Ideogram V3 modelini kullanarak eşzamanlı olarak görüntüler oluşturur.

Metin istemlerinden normal görüntü oluşturmayı ve maske ile görüntü düzenlemeyi destekler.
Görüntü bağlantıları sınırlı bir süre için mevcuttur; görüntüyü saklamak isterseniz indirmeniz gerekir.`,display_name:"Ideogram V3",inputs:{aspect_ratio:{name:"en_boy_oranı",tooltip:"Görüntü oluşturma için en boy oranı. Çözünürlük Otomatik olarak ayarlanmadıysa yoksayılır."},control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü",tooltip:"Görüntü düzenleme için isteğe bağlı referans görüntü."},magic_prompt_option:{name:"sihirli_istem_seçeneği",tooltip:"Üretimde MagicPrompt'un kullanılıp kullanılmayacağını belirleyin"},mask:{name:"maske",tooltip:"İç boyama için isteğe bağlı maske (beyaz alanlar değiştirilecektir)"},num_images:{name:"görüntü_sayısı"},prompt:{name:"istem",tooltip:"Görüntü oluşturma veya düzenleme istemi"},rendering_speed:{name:"oluşturma_hızı",tooltip:"Üretim hızı ve kalite arasındaki dengeyi kontrol eder"},resolution:{name:"çözünürlük",tooltip:"Görüntü oluşturma için çözünürlük. Otomatik olarak ayarlanmadıysa, bu en_boy_oranı ayarını geçersiz kılar."},seed:{name:"tohum"}}},Ze={display_name:"Görüntüleri Toplu İşle",inputs:{image1:{name:"görüntü1"},image2:{name:"görüntü2"}}},qe={display_name:"Görüntü Karıştırma",inputs:{blend_factor:{name:"karıştırma_faktörü"},blend_mode:{name:"karıştırma_modu"},image1:{name:"görüntü1"},image2:{name:"görüntü2"}}},Qe={display_name:"Görüntü Bulanıklaştırma",inputs:{blur_radius:{name:"bulanıklık_yarıçapı"},image:{name:"görüntü"},sigma:{name:"sigma"}}},Je={display_name:"GörüntüRenginiMaskeyeDönüştür",inputs:{color:{name:"renk"},image:{name:"görüntü"}}},$e={display_name:"MaskeliGörüntüBirleştirme",inputs:{destination:{name:"hedef"},mask:{name:"maske"},resize_source:{name:"kaynağı_yeniden_boyutlandır"},source:{name:"kaynak"},x:{name:"x"},y:{name:"y"}}},ea={display_name:"Görüntü Kırp",inputs:{height:{name:"yükseklik"},image:{name:"görüntü"},width:{name:"genişlik"},x:{name:"x"},y:{name:"y"}}},aa={display_name:"TopluİşlemdenGörüntü",inputs:{batch_index:{name:"toplu_indeks"},image:{name:"görüntü"},length:{name:"uzunluk"}}},na={display_name:"Görüntüyü Ters Çevir",inputs:{image:{name:"görüntü"}}},ia={display_name:"Sadece Görüntü Kontrol Noktası Yükleyici (img2vid modeli)",inputs:{ckpt_name:{name:"ckpt_adı"}}},la={display_name:"SadeceGörüntüKontrolNoktasıKaydet",inputs:{clip_vision:{name:"clip_görü"},filename_prefix:{name:"dosyaadı_öneki"},model:{name:"model"},vae:{name:"vae"}}},ta={display_name:"Dış Boyama için Görüntüyü Doldur",inputs:{bottom:{name:"alt"},feathering:{name:"yumuşatma"},image:{name:"görüntü"},left:{name:"sol"},right:{name:"sağ"},top:{name:"üst"}}},oa={display_name:"Görüntü Nicemleme",inputs:{colors:{name:"renkler"},dither:{name:"titreşim"},image:{name:"görüntü"}}},ma={display_name:"GörüntüRGB'denYUV'ye",inputs:{image:{name:"görüntü"}},outputs:{0:{name:"Y"},1:{name:"U"},2:{name:"V"}}},ra={display_name:"Görüntüyü Büyüt",inputs:{crop:{name:"kırp"},height:{name:"yükseklik"},image:{name:"görüntü"},upscale_method:{name:"büyütme_yöntemi"},width:{name:"genişlik"}}},sa={display_name:"Görüntüyü Oranla Büyüt",inputs:{image:{name:"görüntü"},scale_by:{name:"oranla_büyüt"},upscale_method:{name:"büyütme_yöntemi"}}},_a={display_name:"Görüntüyü Toplam Piksele Göre Ölçekle",inputs:{image:{name:"görüntü"},megapixels:{name:"megapiksel"},upscale_method:{name:"büyütme_yöntemi"}}},ka={display_name:"Görüntü Keskinleştir",inputs:{alpha:{name:"alfa"},image:{name:"görüntü"},sharpen_radius:{name:"keskinleştirme_yarıçapı"},sigma:{name:"sigma"}}},da={display_name:"Görüntüyü Maskeye Dönüştür",inputs:{channel:{name:"kanal"},image:{name:"görüntü"}}},pa={display_name:"Görüntüyü Büyüt (Model kullanarak)",inputs:{image:{name:"görüntü"},upscale_model:{name:"büyütme_modeli"}}},ua={display_name:"GörüntüYUV'denRGB'ye",inputs:{U:{name:"U"},V:{name:"V"},Y:{name:"Y"}}},ca={display_name:"İçBoyaModelKoşullandırma",inputs:{mask:{name:"maske"},negative:{name:"negatif"},noise_mask:{name:"gürültü_maskesi",tooltip:"Gizli değişkene bir gürültü maskesi ekleyin, böylece örnekleme yalnızca maske içinde gerçekleşir. Modele bağlı olarak sonuçları iyileştirebilir veya tamamen bozabilir."},pixels:{name:"pikseller"},positive:{name:"pozitif"},vae:{name:"vae"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},ga={display_name:"InstructPixToPixKoşullandırma",inputs:{negative:{name:"negatif"},pixels:{name:"pikseller"},positive:{name:"pozitif"},vae:{name:"vae"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},ba={display_name:"Maskeyi Ters Çevir",inputs:{mask:{name:"maske"}}},ya={display_name:"Görüntüyü Alfa ile Birleştir",inputs:{alpha:{name:"alfa"},image:{name:"görüntü"}}},fa={description:"Gizli görüntünün gürültüsünü azaltmak için sağlanan modeli, pozitif ve negatif koşullandırmayı kullanır.",display_name:"KSampler",inputs:{cfg:{name:"cfg",tooltip:"Sınıflandırıcısız Rehberlik ölçeği, yaratıcılık ile isteme bağlılık arasında bir denge kurar. Daha yüksek değerler, isteme daha yakından eşleşen görüntülerle sonuçlanır, ancak çok yüksek değerler kaliteyi olumsuz etkiler."},control_after_generate:{name:"oluşturduktan sonra kontrol et"},denoise:{name:"gürültü_azaltma",tooltip:"Uygulanan gürültü giderme miktarı, daha düşük değerler ilk görüntünün yapısını koruyarak görüntüden görüntüye örneklemeye olanak tanır."},latent_image:{name:"gizli_görüntü",tooltip:"Gürültüsü giderilecek gizli görüntü."},model:{name:"model",tooltip:"Giriş gizli değişkeninin gürültüsünü azaltmak için kullanılan model."},negative:{name:"negatif",tooltip:"Görüntüden hariç tutmak istediğiniz özellikleri tanımlayan koşullandırma."},positive:{name:"pozitif",tooltip:"Görüntüye dahil etmek istediğiniz özellikleri tanımlayan koşullandırma."},sampler_name:{name:"örnekleyici_adı",tooltip:"Örnekleme sırasında kullanılan algoritma, bu, oluşturulan çıktının kalitesini, hızını ve stilini etkileyebilir."},scheduler:{name:"zamanlayıcı",tooltip:"Zamanlayıcı, görüntüyü oluşturmak için gürültünün kademeli olarak nasıl kaldırılacağını kontrol eder."},seed:{name:"tohum",tooltip:"Gürültüyü oluşturmak için kullanılan rastgele tohum."},steps:{name:"adımlar",tooltip:"Gürültü giderme işleminde kullanılan adım sayısı."}},outputs:{0:{tooltip:"Gürültüsü giderilmiş gizli değişken."}}},ha={display_name:"KSampler (Gelişmiş)",inputs:{add_noise:{name:"gürültü_ekle"},cfg:{name:"cfg"},control_after_generate:{name:"oluşturduktan sonra kontrol et"},end_at_step:{name:"bitiş_adımı"},latent_image:{name:"gizli_görüntü"},model:{name:"model"},negative:{name:"negatif"},noise_seed:{name:"gürültü_tohumu"},positive:{name:"pozitif"},return_with_leftover_noise:{name:"kalan_gürültüyle_dön"},sampler_name:{name:"örnekleyici_adı"},scheduler:{name:"zamanlayıcı"},start_at_step:{name:"başlangıç_adımı"},steps:{name:"adımlar"}}},za={display_name:"KSamplerSeç",inputs:{sampler_name:{name:"örnekleyici_adı"}}},va={display_name:"KarrasZamanlayıcı",inputs:{rho:{name:"rho"},sigma_max:{name:"sigma_maks"},sigma_min:{name:"sigma_min"},steps:{name:"adımlar"}}},Sa={description:"Gerçek dünya sinematografisini simüle eden profesyonel kamera hareketleriyle durağan görüntüleri sinematik videolara dönüştürün. Orijinal görüntünüze odaklanırken yakınlaştırma, döndürme, kaydırma, eğme ve birinci şahıs görünümü dahil olmak üzere sanal kamera eylemlerini kontrol edin.",display_name:"Kling Görüntüden Videoya (Kamera Kontrolü)",inputs:{aspect_ratio:{name:"en_boy_oranı"},camera_control:{name:"kamera_kontrolü",tooltip:"Kling Kamera Kontrolleri düğümü kullanılarak oluşturulabilir. Video oluşturma sırasında kamera hareketini ve devinimini kontrol eder."},cfg_scale:{name:"cfg_ölçeği"},negative_prompt:{name:"negatif_istem",tooltip:"Negatif metin istemi"},prompt:{name:"istem",tooltip:"Pozitif metin istemi"},start_frame:{name:"başlangıç_karesi",tooltip:"Referans Görüntü - URL veya Base64 kodlu dize, 10 MB'ı geçemez, çözünürlük 300*300 pikselden az olamaz, en boy oranı 1:2.5 ~ 2.5:1 arasındadır. Base64, data:image önekini içermemelidir."}},outputs:{1:{name:"video_kimliği"},2:{name:"süre"}}},La={description:"Gerçek dünya sinematografisini simüle eden profesyonel kamera hareketleriyle metni sinematik videolara dönüştürün. Orijinal metninize odaklanırken yakınlaştırma, döndürme, kaydırma, eğme ve birinci şahıs görünümü dahil olmak üzere sanal kamera eylemlerini kontrol edin.",display_name:"Kling Metinden Videoya (Kamera Kontrolü)",inputs:{aspect_ratio:{name:"en_boy_oranı"},camera_control:{name:"kamera_kontrolü",tooltip:"Kling Kamera Kontrolleri düğümü kullanılarak oluşturulabilir. Video oluşturma sırasında kamera hareketini ve devinimini kontrol eder."},cfg_scale:{name:"cfg_ölçeği"},negative_prompt:{name:"negatif_istem",tooltip:"Negatif metin istemi"},prompt:{name:"istem",tooltip:"Pozitif metin istemi"}},outputs:{1:{name:"video_kimliği"},2:{name:"süre"}}},Ca={description:"Kling Kamera Kontrolleri ve hareket kontrolü efektleri için yapılandırma seçeneklerini belirtmeye olanak tanır.",display_name:"Kling Kamera Kontrolleri",inputs:{camera_control_type:{name:"kamera_kontrol_türü"},horizontal_movement:{name:"yatay_hareket",tooltip:"Kameranın yatay eksen (x ekseni) boyunca hareketini kontrol eder. Negatif sola, pozitif sağa gösterir"},pan:{name:"kaydırma",tooltip:"Kameranın dikey düzlemde (x ekseni) dönüşünü kontrol eder. Negatif aşağı dönüşü, pozitif yukarı dönüşü gösterir."},roll:{name:"yuvarlanma",tooltip:"Kameranın yuvarlanma miktarını (z ekseni) kontrol eder. Negatif saat yönünün tersini, pozitif saat yönünü gösterir."},tilt:{name:"eğme",tooltip:"Kameranın yatay düzlemde (y ekseni) dönüşünü kontrol eder. Negatif sola dönüşü, pozitif sağa dönüşü gösterir."},vertical_movement:{name:"dikey_hareket",tooltip:"Kameranın dikey eksen (y ekseni) boyunca hareketini kontrol eder. Negatif aşağı, pozitif yukarı gösterir."},zoom:{name:"yakınlaştırma",tooltip:"Kameranın odak uzaklığındaki değişikliği kontrol eder. Negatif daha dar bir görüş alanını, pozitif daha geniş bir görüş alanını gösterir."}},outputs:{0:{name:"kamera_kontrolü"}}},Ma={description:"Efekt_sahnesine dayalı bir video oluştururken farklı özel efektler elde edin. İlk görüntü sol tarafa, ikinci görüntü ise birleşimin sağ tarafına konumlandırılacaktır.",display_name:"Kling İkili Karakter Video Efektleri",inputs:{duration:{name:"süre"},effect_scene:{name:"efekt_sahnesi"},image_left:{name:"sol_görüntü",tooltip:"Sol taraf görüntüsü"},image_right:{name:"sağ_görüntü",tooltip:"Sağ taraf görüntüsü"},mode:{name:"mod"},model_name:{name:"model_adı"}},outputs:{1:{name:"süre"}}},Ga={description:"Kling Görüntüden Videoya Düğümü",display_name:"Kling Görüntüden Videoya",inputs:{aspect_ratio:{name:"en_boy_oranı"},cfg_scale:{name:"cfg_ölçeği"},duration:{name:"süre"},mode:{name:"mod"},model_name:{name:"model_adı"},negative_prompt:{name:"negatif_istem",tooltip:"Negatif metin istemi"},prompt:{name:"istem",tooltip:"Pozitif metin istemi"},start_frame:{name:"başlangıç_karesi",tooltip:"Referans Görüntü - URL veya Base64 kodlu dize, 10 MB'ı geçemez, çözünürlük 300*300 pikselden az olamaz, en boy oranı 1:2.5 ~ 2.5:1 arasındadır. Base64, data:image önekini içermemelidir."}},outputs:{1:{name:"video_kimliği"},2:{name:"süre"}}},Va={description:"Kling Görüntü Oluşturma Düğümü. İsteğe bağlı bir referans görüntü ile bir metin isteminden bir görüntü oluşturun.",display_name:"Kling Görüntü Oluşturma",inputs:{aspect_ratio:{name:"en_boy_oranı"},human_fidelity:{name:"insan_sadakati",tooltip:"Konu referans benzerliği"},image:{name:"görüntü"},image_fidelity:{name:"görüntü_sadakati",tooltip:"Kullanıcı tarafından yüklenen görüntüler için referans yoğunluğu"},image_type:{name:"görüntü_türü"},model_name:{name:"model_adı"},n:{name:"n",tooltip:"Oluşturulan görüntü sayısı"},negative_prompt:{name:"negatif_istem",tooltip:"Negatif metin istemi"},prompt:{name:"istem",tooltip:"Pozitif metin istemi"}}},Ia={description:"Kling Dudak Senkronizasyonu Sesten Videoya Düğümü. Bir video dosyasındaki ağız hareketlerini bir ses dosyasının ses içeriğiyle senkronize eder.",display_name:"Kling Dudak Senkronizasyonu Video ile Ses",inputs:{audio:{name:"ses"},video:{name:"video"},voice_language:{name:"ses_dili"}},outputs:{1:{name:"video_kimliği"},2:{name:"süre"}}},Aa={description:"Kling Dudak Senkronizasyonu Metinden Videoya Düğümü. Bir video dosyasındaki ağız hareketlerini bir metin istemiyle senkronize eder.",display_name:"Kling Dudak Senkronizasyonu Video ile Metin",inputs:{text:{name:"metin",tooltip:"Dudak Senkronizasyonu Video Oluşturma için Metin İçeriği. Mod metinden videoya olduğunda gereklidir. Maksimum uzunluk 120 karakterdir."},video:{name:"video"},voice:{name:"ses"},voice_speed:{name:"ses_hızı",tooltip:"Konuşma Hızı. Geçerli aralık: 0.8~2.0, bir ondalık basamağa kadar doğru."}},outputs:{1:{name:"video_kimliği"},2:{name:"süre"}}},Pa={description:"Efekt_sahnesine dayalı bir video oluştururken farklı özel efektler elde edin.",display_name:"Kling Video Efektleri",inputs:{duration:{name:"süre"},effect_scene:{name:"efekt_sahnesi"},image:{name:"görüntü",tooltip:" Referans Görüntü. URL veya Base64 kodlu dize (data:image öneki olmadan). Dosya boyutu 10 MB'ı geçemez, çözünürlük 300*300 pikselden az olamaz, en boy oranı 1:2.5 ~ 2.5:1 arasındadır"},model_name:{name:"model_adı"}},outputs:{1:{name:"video_kimliği"},2:{name:"süre"}}},Da={description:"Sağladığınız başlangıç ve bitiş görüntüleri arasında geçiş yapan bir video dizisi oluşturun. Düğüm, aradaki tüm kareleri oluşturarak ilk kareden son kareye pürüzsüz bir dönüşüm üretir.",display_name:"Kling Başlangıç-Bitiş Karesinden Videoya",inputs:{aspect_ratio:{name:"en_boy_oranı"},cfg_scale:{name:"cfg_ölçeği"},end_frame:{name:"bitiş_karesi",tooltip:"Referans Görüntü - Bitiş karesi kontrolü. URL veya Base64 kodlu dize, 10 MB'ı geçemez, çözünürlük 300*300 pikselden az olamaz. Base64, data:image önekini içermemelidir."},mode:{name:"mod",tooltip:"Video oluşturma için kullanılacak yapılandırma, şu formatı izler: mod / süre / model_adı."},negative_prompt:{name:"negatif_istem",tooltip:"Negatif metin istemi"},prompt:{name:"istem",tooltip:"Pozitif metin istemi"},start_frame:{name:"başlangıç_karesi",tooltip:"Referans Görüntü - URL veya Base64 kodlu dize, 10 MB'ı geçemez, çözünürlük 300*300 pikselden az olamaz, en boy oranı 1:2.5 ~ 2.5:1 arasındadır. Base64, data:image önekini içermemelidir."}},outputs:{1:{name:"video_kimliği"},2:{name:"süre"}}},Ka={description:"Kling Metinden Videoya Düğümü",display_name:"Kling Metinden Videoya",inputs:{aspect_ratio:{name:"en_boy_oranı"},cfg_scale:{name:"cfg_ölçeği"},mode:{name:"mod",tooltip:"Video oluşturma için kullanılacak yapılandırma, şu formatı izler: mod / süre / model_adı."},negative_prompt:{name:"negatif_istem",tooltip:"Negatif metin istemi"},prompt:{name:"istem",tooltip:"Pozitif metin istemi"}},outputs:{1:{name:"video_kimliği"},2:{name:"süre"}}},xa={description:"Kling Video Uzatma Düğümü. Diğer Kling düğümleri tarafından yapılan videoları uzatın. video_id, diğer Kling Düğümleri kullanılarak oluşturulur.",display_name:"Kling Video Uzatma",inputs:{cfg_scale:{name:"cfg_ölçeği"},negative_prompt:{name:"negatif_istem",tooltip:"Uzatılmış videoda kaçınılması gereken öğeler için negatif metin istemi"},prompt:{name:"istem",tooltip:"Video uzatmayı yönlendirmek için pozitif metin istemi"},video_id:{name:"video_kimliği",tooltip:"Uzatılacak videonun kimliği. Metinden videoya, görüntüden videoya ve önceki video uzatma işlemlerinden oluşturulan videoları destekler. Uzatmadan sonra toplam süre 3 dakikayı geçemez."}},outputs:{1:{name:"video_kimliği"},2:{name:"süre"}}},Ba={description:"Kling Sanal Deneme Düğümü. İnsan üzerine kıyafet denemek için bir insan resmi ve bir kıyafet resmi girin.",display_name:"Kling Sanal Deneme",inputs:{cloth_image:{name:"kıyafet_görüntüsü"},human_image:{name:"insan_görüntüsü"},model_name:{name:"model_adı"}}},Ta={display_name:"LTXVRehberEkle",inputs:{frame_idx:{name:"kare_indeksi",tooltip:"Koşullandırmanın başlayacağı kare indeksi. Tek kareli görüntüler veya 1-8 kareli videolar için herhangi bir kare_indeksi değeri kabul edilebilir. 9+ kareli videolar için kare_indeksi 8'e bölünebilir olmalıdır, aksi takdirde en yakın 8'in katına yuvarlanacaktır. Negatif değerler videonun sonundan sayılır."},image:{name:"görüntü",tooltip:"Gizli videoyu koşullandırmak için görüntü veya video. 8*n + 1 kare olmalıdır. Video 8*n + 1 kare değilse, en yakın 8*n + 1 kareye kırpılacaktır."},latent:{name:"gizli"},negative:{name:"negatif"},positive:{name:"pozitif"},strength:{name:"güç"},vae:{name:"vae"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},Ea={display_name:"LTXVKoşullandırma",inputs:{frame_rate:{name:"kare_hızı"},negative:{name:"negatif"},positive:{name:"pozitif"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"}}},Na={display_name:"LTXVRehberleriKırp",inputs:{latent:{name:"gizli"},negative:{name:"negatif"},positive:{name:"pozitif"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},Ra={display_name:"LTXVGörüntüdenVideoya",inputs:{batch_size:{name:"toplu_boyut"},height:{name:"yükseklik"},image:{name:"görüntü"},length:{name:"uzunluk"},negative:{name:"negatif"},positive:{name:"pozitif"},strength:{name:"güç"},vae:{name:"vae"},width:{name:"genişlik"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},Fa={display_name:"LTXVÖnİşleme",inputs:{image:{name:"görüntü"},img_compression:{name:"görüntü_sıkıştırma",tooltip:"Görüntüye uygulanacak sıkıştırma miktarı."}},outputs:{0:{name:"çıktı_görüntüsü"}}},Ua={display_name:"LTXVZamanlayıcı",inputs:{base_shift:{name:"temel_kaydırma"},latent:{name:"gizli"},max_shift:{name:"maks_kaydırma"},steps:{name:"adımlar"},stretch:{name:"uzatma",tooltip:"Sigmaları [terminal, 1] aralığında olacak şekilde uzatın."},terminal:{name:"terminal",tooltip:"Uzatmadan sonra sigmaların terminal değeri."}}},wa={display_name:"LaplaceZamanlayıcı",inputs:{beta:{name:"beta"},mu:{name:"mu"},sigma_max:{name:"sigma_maks"},sigma_min:{name:"sigma_min"},steps:{name:"adımlar"}}},Oa={display_name:"GizliEkle",inputs:{samples1:{name:"örnekler1"},samples2:{name:"örnekler2"}}},ja={display_name:"GizliİşlemUygula",inputs:{operation:{name:"işlem"},samples:{name:"örnekler"}}},Ha={display_name:"GizliİşlemUygulaCFG",inputs:{model:{name:"model"},operation:{name:"işlem"}}},Ya={display_name:"GizliTopluİş",inputs:{samples1:{name:"örnekler1"},samples2:{name:"örnekler2"}}},Wa={display_name:"GizliTopluTohumDavranışı",inputs:{samples:{name:"örnekler"},seed_behavior:{name:"tohum_davranışı"}}},Xa={display_name:"Gizli Karıştırma",inputs:{blend_factor:{name:"karıştırma_faktörü"},samples1:{name:"örnekler1"},samples2:{name:"örnekler2"}}},Za={display_name:"Gizli Birleştirme",inputs:{feather:{name:"yumuşatma"},samples_from:{name:"kaynak_örnekler"},samples_to:{name:"hedef_örnekler"},x:{name:"x"},y:{name:"y"}}},qa={display_name:"MaskeliGizliBirleştirme",inputs:{destination:{name:"hedef"},mask:{name:"maske"},resize_source:{name:"kaynağı_yeniden_boyutlandır"},source:{name:"kaynak"},x:{name:"x"},y:{name:"y"}}},Qa={display_name:"Gizli Değişkeni Kırp",inputs:{height:{name:"yükseklik"},samples:{name:"örnekler"},width:{name:"genişlik"},x:{name:"x"},y:{name:"y"}}},Ja={display_name:"Gizli Değişkeni Çevir",inputs:{flip_method:{name:"çevirme_yöntemi"},samples:{name:"örnekler"}}},$a={display_name:"Toplu İşlemden Gizli Değişken",inputs:{batch_index:{name:"toplu_indeks"},length:{name:"uzunluk"},samples:{name:"örnekler"}}},en={display_name:"GizliAraDeğerleme",inputs:{ratio:{name:"oran"},samples1:{name:"örnekler1"},samples2:{name:"örnekler2"}}},an={display_name:"GizliÇarpma",inputs:{multiplier:{name:"çarpan"},samples:{name:"örnekler"}}},nn={display_name:"GizliİşlemKeskinleştirme",inputs:{alpha:{name:"alfa"},sharpen_radius:{name:"keskinleştirme_yarıçapı"},sigma:{name:"sigma"}}},ln={display_name:"GizliİşlemTonEşlemeReinhard",inputs:{multiplier:{name:"çarpan"}}},tn={display_name:"Gizli Değişkeni Döndür",inputs:{rotation:{name:"döndürme"},samples:{name:"örnekler"}}},on={display_name:"GizliÇıkarma",inputs:{samples1:{name:"örnekler1"},samples2:{name:"örnekler2"}}},mn={display_name:"Gizli Değişkeni Büyüt",inputs:{crop:{name:"kırp"},height:{name:"yükseklik"},samples:{name:"örnekler"},upscale_method:{name:"büyütme_yöntemi"},width:{name:"genişlik"}}},rn={display_name:"Gizli Değişkeni Oranla Büyüt",inputs:{samples:{name:"örnekler"},scale_by:{name:"oranla_büyüt"},upscale_method:{name:"büyütme_yöntemi"}}},sn={display_name:"3D Yükle",inputs:{clear:{},height:{name:"yükseklik"},image:{name:"görüntü"},model_file:{name:"model_dosyası"},"upload 3d model":{},width:{name:"genişlik"}},outputs:{0:{name:"görüntü"},1:{name:"maske"},2:{name:"ağ_yolu"},3:{name:"normal"},4:{name:"çizgi_sanatı"},5:{name:"kamera_bilgisi"}}},_n={display_name:"3D Yükle - Animasyon",inputs:{height:{name:"yükseklik"},image:{name:"görüntü"},model_file:{name:"model_dosyası"},width:{name:"genişlik"}},outputs:{0:{name:"görüntü"},1:{name:"maske"},2:{name:"ağ_yolu"},3:{name:"normal"},4:{name:"kamera_bilgisi"}}},kn={display_name:"Ses Yükle",inputs:{audio:{name:"ses"},audioUI:{name:"sesArayüzü"},upload:{name:"yüklenecek dosyayı seçin"}}},dn={display_name:"Görüntü Yükle",inputs:{image:{name:"görüntü"},upload:{name:"yüklenecek dosyayı seçin"}}},pn={display_name:"Görüntü Yükle (Maske olarak)",inputs:{channel:{name:"kanal"},image:{name:"görüntü"},upload:{name:"yüklenecek dosyayı seçin"}}},un={description:"Çıktı klasöründen bir görüntü yükleyin. Yenile düğmesine tıklandığında, düğüm görüntü listesini güncelleyecek ve otomatik olarak ilk görüntüyü seçecek, bu da kolay yinelemeye olanak tanıyacaktır.",display_name:"Görüntü Yükle (Çıktılardan)",inputs:{image:{name:"görüntü"},refresh:{},upload:{name:"yüklenecek dosyayı seçin"}}},cn={display_name:"GizliYükle",inputs:{latent:{name:"gizli"}}},gn={display_name:"Video Yükle",inputs:{file:{name:"dosya"},upload:{name:"yüklenecek dosyayı seçin"}}},bn={description:"LoRA'lar, difüzyon ve CLIP modellerini değiştirmek, gizli değişkenlerin gürültüsünün giderilme şeklini değiştirmek (örneğin stiller uygulamak) için kullanılır. Birden fazla LoRA düğümü birbirine bağlanabilir.",display_name:"LoRA Yükle",inputs:{clip:{name:"clip",tooltip:"LoRA'nın uygulanacağı CLIP modeli."},lora_name:{name:"lora_adı",tooltip:"LoRA'nın adı."},model:{name:"model",tooltip:"LoRA'nın uygulanacağı difüzyon modeli."},strength_clip:{name:"clip_gücü",tooltip:"CLIP modelinin ne kadar güçlü değiştirileceği. Bu değer negatif olabilir."},strength_model:{name:"model_gücü",tooltip:"Difüzyon modelinin ne kadar güçlü değiştirileceği. Bu değer negatif olabilir."}},outputs:{0:{tooltip:"Değiştirilmiş difüzyon modeli."},1:{tooltip:"Değiştirilmiş CLIP modeli."}}},yn={description:"LoRA'lar, difüzyon ve CLIP modellerini değiştirmek, gizli değişkenlerin gürültüsünün giderilme şeklini değiştirmek (örneğin stiller uygulamak) için kullanılır. Birden fazla LoRA düğümü birbirine bağlanabilir.",display_name:"SadeceModelLoRA Yükleyici",inputs:{lora_name:{name:"lora_adı"},model:{name:"model"},strength_model:{name:"model_gücü"}},outputs:{0:{tooltip:"Değiştirilmiş difüzyon modeli."}}},fn={display_name:"Lora'yı Çıkar ve Kaydet",inputs:{bias_diff:{name:"yanlılık_farkı"},filename_prefix:{name:"dosyaadı_öneki"},lora_type:{name:"lora_türü"},model_diff:{name:"model_farkı",tooltip:"Lora'ya dönüştürülecek ModelSubtract çıktısı."},rank:{name:"rütbe"},text_encoder_diff:{name:"metin_kodlayıcı_farkı",tooltip:"Lora'ya dönüştürülecek CLIPSubtract çıktısı."}}},hn={display_name:"LotusKoşullandırma",outputs:{0:{name:"koşullandırma"}}},zn={description:"Luma Metinden Videoya ve Luma Görüntüden Videoya düğümleriyle kullanılmak üzere bir veya daha fazla Kamera Kavramı tutar.",display_name:"Luma Kavramları",inputs:{concept1:{name:"kavram1"},concept2:{name:"kavram2"},concept3:{name:"kavram3"},concept4:{name:"kavram4"},luma_concepts:{name:"luma_kavramları",tooltip:"Burada seçilenlere eklemek için isteğe bağlı Kamera Kavramları."}},outputs:{0:{name:"luma_kavramları"}}},vn={description:"İstem ve en boy oranına göre görüntüleri eşzamanlı olarak değiştirir.",display_name:"Luma Görüntüden Görüntüye",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü"},image_weight:{name:"görüntü_ağırlığı",tooltip:"Görüntünün ağırlığı; 1.0'a ne kadar yakınsa, görüntü o kadar az değiştirilir."},model:{name:"model"},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi"},seed:{name:"tohum",tooltip:"Düğümün yeniden çalışıp çalışmayacağını belirlemek için tohum; gerçek sonuçlar tohumdan bağımsız olarak belirleyici değildir."}}},Sn={description:"İstem ve en boy oranına göre görüntüleri eşzamanlı olarak oluşturur.",display_name:"Luma Metinden Görüntüye",inputs:{aspect_ratio:{name:"en_boy_oranı"},character_image:{name:"karakter_görüntüsü",tooltip:"Karakter referans görüntüleri; birden fazla toplu olabilir, en fazla 4 görüntü dikkate alınabilir."},control_after_generate:{name:"oluşturduktan sonra kontrol et"},image_luma_ref:{name:"görüntü_luma_referansı",tooltip:"Giriş görüntüleriyle üretimi etkilemek için Luma Referans düğümü bağlantısı; en fazla 4 görüntü dikkate alınabilir."},model:{name:"model"},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi"},seed:{name:"tohum",tooltip:"Düğümün yeniden çalışıp çalışmayacağını belirlemek için tohum; gerçek sonuçlar tohumdan bağımsız olarak belirleyici değildir."},style_image:{name:"stil_görüntüsü",tooltip:"Stil referans görüntüsü; yalnızca 1 görüntü kullanılacaktır."},style_image_weight:{name:"stil_görüntüsü_ağırlığı",tooltip:"Stil görüntüsünün ağırlığı. Stil_görüntüsü sağlanmazsa yoksayılır."}}},Ln={description:"İstem, giriş görüntüleri ve çıktı_boyutuna göre videoları eşzamanlı olarak oluşturur.",display_name:"Luma Görüntüden Videoya",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},duration:{name:"süre"},first_image:{name:"ilk_görüntü",tooltip:"Oluşturulan videonun ilk karesi."},last_image:{name:"son_görüntü",tooltip:"Oluşturulan videonun son karesi."},loop:{name:"döngü"},luma_concepts:{name:"luma_kavramları",tooltip:"Luma Kavramları düğümü aracılığıyla kamera hareketini dikte etmek için isteğe bağlı Kamera Kavramları."},model:{name:"model"},prompt:{name:"istem",tooltip:"Video oluşturma istemi"},resolution:{name:"çözünürlük"},seed:{name:"tohum",tooltip:"Düğümün yeniden çalışıp çalışmayacağını belirlemek için tohum; gerçek sonuçlar tohumdan bağımsız olarak belirleyici değildir."}}},Cn={description:"Luma Görüntü Oluştur düğümüyle kullanılmak üzere bir görüntü ve ağırlık tutar.",display_name:"Luma Referansı",inputs:{image:{name:"görüntü",tooltip:"Referans olarak kullanılacak görüntü."},luma_ref:{name:"luma_referansı"},weight:{name:"ağırlık",tooltip:"Görüntü referansının ağırlığı."}},outputs:{0:{name:"luma_referansı"}}},Mn={description:"İstem ve çıktı_boyutuna göre videoları eşzamanlı olarak oluşturur.",display_name:"Luma Metinden Videoya",inputs:{aspect_ratio:{name:"en_boy_oranı"},control_after_generate:{name:"oluşturduktan sonra kontrol et"},duration:{name:"süre"},loop:{name:"döngü"},luma_concepts:{name:"luma_kavramları",tooltip:"Luma Kavramları düğümü aracılığıyla kamera hareketini dikte etmek için isteğe bağlı Kamera Kavramları."},model:{name:"model"},prompt:{name:"istem",tooltip:"Video oluşturma istemi"},resolution:{name:"çözünürlük"},seed:{name:"tohum",tooltip:"Düğümün yeniden çalışıp çalışmayacağını belirlemek için tohum; gerçek sonuçlar tohumdan bağımsız olarak belirleyici değildir."}}},Gn={description:"Rehberliği, negatif istem arasındaki farktan ziyade pozitif istemin 'yönüne' daha fazla ölçeklenecek şekilde değiştirin.",display_name:"Mahiro o kadar sevimli ki daha iyi bir rehberlik fonksiyonunu hak ediyor!! (。・ω・。)",inputs:{model:{name:"model"}},outputs:{0:{name:"yamalı_model"}}},Vn={display_name:"MaskeBirleştirme",inputs:{destination:{name:"hedef"},operation:{name:"işlem"},source:{name:"kaynak"},x:{name:"x"},y:{name:"y"}}},In={description:"Giriş görüntülerini ComfyUI çıktı dizininize kaydeder.",display_name:"MaskeÖnizleme",inputs:{mask:{name:"maske"}}},An={display_name:"Maskeyi Görüntüye Dönüştür",inputs:{mask:{name:"maske"}}},Pn={description:"MiniMax'in API'sini kullanarak bir görüntüden ve istemlerden videolar oluşturur",display_name:"MiniMax Görüntüden Videoya",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü",tooltip:"Video oluşturmanın ilk karesi olarak kullanılacak görüntü"},model:{name:"model",tooltip:"Video oluşturma için kullanılacak model"},prompt_text:{name:"istem_metni",tooltip:"Video oluşturmayı yönlendirecek metin istemi"},seed:{name:"tohum",tooltip:"Gürültüyü oluşturmak için kullanılan rastgele tohum."}}},Dn={description:"MiniMax'in API'sini kullanarak istemlerden videolar oluşturur",display_name:"MiniMax Metinden Videoya",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},model:{name:"model",tooltip:"Video oluşturma için kullanılacak model"},prompt_text:{name:"istem_metni",tooltip:"Video oluşturmayı yönlendirecek metin istemi"},seed:{name:"tohum",tooltip:"Gürültüyü oluşturmak için kullanılan rastgele tohum."}}},Kn={display_name:"ModelHesaplamaVeriTürü",inputs:{dtype:{name:"veri_türü"},model:{name:"model"}}},xn={display_name:"ModelBirleştirmeEkle",inputs:{model1:{name:"model1"},model2:{name:"model2"}}},Bn={display_name:"ModelBirleştirmeAuraflow",inputs:{cond_seq_linear_:{name:"koşul_dizi_doğrusal."},double_layers_0_:{name:"çift_katmanlar.0."},double_layers_1_:{name:"çift_katmanlar.1."},double_layers_2_:{name:"çift_katmanlar.2."},double_layers_3_:{name:"çift_katmanlar.3."},final_linear_:{name:"son_doğrusal."},init_x_linear_:{name:"başlangıç_x_doğrusal."},modF_:{name:"modF."},model1:{name:"model1"},model2:{name:"model2"},positional_encoding:{name:"konumsal_kodlama"},register_tokens:{name:"kayıt_jetonları"},single_layers_0_:{name:"tek_katmanlar.0."},single_layers_10_:{name:"tek_katmanlar.10."},single_layers_11_:{name:"tek_katmanlar.11."},single_layers_12_:{name:"tek_katmanlar.12."},single_layers_13_:{name:"tek_katmanlar.13."},single_layers_14_:{name:"tek_katmanlar.14."},single_layers_15_:{name:"tek_katmanlar.15."},single_layers_16_:{name:"tek_katmanlar.16."},single_layers_17_:{name:"tek_katmanlar.17."},single_layers_18_:{name:"tek_katmanlar.18."},single_layers_19_:{name:"tek_katmanlar.19."},single_layers_1_:{name:"tek_katmanlar.1."},single_layers_20_:{name:"tek_katmanlar.20."},single_layers_21_:{name:"tek_katmanlar.21."},single_layers_22_:{name:"tek_katmanlar.22."},single_layers_23_:{name:"tek_katmanlar.23."},single_layers_24_:{name:"tek_katmanlar.24."},single_layers_25_:{name:"tek_katmanlar.25."},single_layers_26_:{name:"tek_katmanlar.26."},single_layers_27_:{name:"tek_katmanlar.27."},single_layers_28_:{name:"tek_katmanlar.28."},single_layers_29_:{name:"tek_katmanlar.29."},single_layers_2_:{name:"tek_katmanlar.2."},single_layers_30_:{name:"tek_katmanlar.30."},single_layers_31_:{name:"tek_katmanlar.31."},single_layers_3_:{name:"tek_katmanlar.3."},single_layers_4_:{name:"tek_katmanlar.4."},single_layers_5_:{name:"tek_katmanlar.5."},single_layers_6_:{name:"tek_katmanlar.6."},single_layers_7_:{name:"tek_katmanlar.7."},single_layers_8_:{name:"tek_katmanlar.8."},single_layers_9_:{name:"tek_katmanlar.9."},t_embedder_:{name:"t_gömücü."}}},Tn={display_name:"ModelBloklarınıBirleştir",inputs:{input:{name:"giriş"},middle:{name:"orta"},model1:{name:"model1"},model2:{name:"model2"},out:{name:"çıktı"}}},En={display_name:"ModelBirleştirmeCosmos14B",inputs:{affline_norm_:{name:"afin_norm."},blocks_block0_:{name:"bloklar.blok0."},blocks_block10_:{name:"bloklar.blok10."},blocks_block11_:{name:"bloklar.blok11."},blocks_block12_:{name:"bloklar.blok12."},blocks_block13_:{name:"bloklar.blok13."},blocks_block14_:{name:"bloklar.blok14."},blocks_block15_:{name:"bloklar.blok15."},blocks_block16_:{name:"bloklar.blok16."},blocks_block17_:{name:"bloklar.blok17."},blocks_block18_:{name:"bloklar.blok18."},blocks_block19_:{name:"bloklar.blok19."},blocks_block1_:{name:"bloklar.blok1."},blocks_block20_:{name:"bloklar.blok20."},blocks_block21_:{name:"bloklar.blok21."},blocks_block22_:{name:"bloklar.blok22."},blocks_block23_:{name:"bloklar.blok23."},blocks_block24_:{name:"bloklar.blok24."},blocks_block25_:{name:"bloklar.blok25."},blocks_block26_:{name:"bloklar.blok26."},blocks_block27_:{name:"bloklar.blok27."},blocks_block28_:{name:"bloklar.blok28."},blocks_block29_:{name:"bloklar.blok29."},blocks_block2_:{name:"bloklar.blok2."},blocks_block30_:{name:"bloklar.blok30."},blocks_block31_:{name:"bloklar.blok31."},blocks_block32_:{name:"bloklar.blok32."},blocks_block33_:{name:"bloklar.blok33."},blocks_block34_:{name:"bloklar.blok34."},blocks_block35_:{name:"bloklar.blok35."},blocks_block3_:{name:"bloklar.blok3."},blocks_block4_:{name:"bloklar.blok4."},blocks_block5_:{name:"bloklar.blok5."},blocks_block6_:{name:"bloklar.blok6."},blocks_block7_:{name:"bloklar.blok7."},blocks_block8_:{name:"bloklar.blok8."},blocks_block9_:{name:"bloklar.blok9."},extra_pos_embedder_:{name:"ek_konum_gömücü."},final_layer_:{name:"son_katman."},model1:{name:"model1"},model2:{name:"model2"},pos_embedder_:{name:"konum_gömücü."},t_embedder_:{name:"t_gömücü."},x_embedder_:{name:"x_gömücü."}}},Nn={display_name:"ModelBirleştirmeCosmos7B",inputs:{affline_norm_:{name:"afin_norm."},blocks_block0_:{name:"bloklar.blok0."},blocks_block10_:{name:"bloklar.blok10."},blocks_block11_:{name:"bloklar.blok11."},blocks_block12_:{name:"bloklar.blok12."},blocks_block13_:{name:"bloklar.blok13."},blocks_block14_:{name:"bloklar.blok14."},blocks_block15_:{name:"bloklar.blok15."},blocks_block16_:{name:"bloklar.blok16."},blocks_block17_:{name:"bloklar.blok17."},blocks_block18_:{name:"bloklar.blok18."},blocks_block19_:{name:"bloklar.blok19."},blocks_block1_:{name:"bloklar.blok1."},blocks_block20_:{name:"bloklar.blok20."},blocks_block21_:{name:"bloklar.blok21."},blocks_block22_:{name:"bloklar.blok22."},blocks_block23_:{name:"bloklar.blok23."},blocks_block24_:{name:"bloklar.blok24."},blocks_block25_:{name:"bloklar.blok25."},blocks_block26_:{name:"bloklar.blok26."},blocks_block27_:{name:"bloklar.blok27."},blocks_block2_:{name:"bloklar.blok2."},blocks_block3_:{name:"bloklar.blok3."},blocks_block4_:{name:"bloklar.blok4."},blocks_block5_:{name:"bloklar.blok5."},blocks_block6_:{name:"bloklar.blok6."},blocks_block7_:{name:"bloklar.blok7."},blocks_block8_:{name:"bloklar.blok8."},blocks_block9_:{name:"bloklar.blok9."},extra_pos_embedder_:{name:"ek_konum_gömücü."},final_layer_:{name:"son_katman."},model1:{name:"model1"},model2:{name:"model2"},pos_embedder_:{name:"konum_gömücü."},t_embedder_:{name:"t_gömücü."},x_embedder_:{name:"x_gömücü."}}},Rn={display_name:"ModelBirleştirmeFlux1",inputs:{double_blocks_0_:{name:"çift_bloklar.0."},double_blocks_10_:{name:"çift_bloklar.10."},double_blocks_11_:{name:"çift_bloklar.11."},double_blocks_12_:{name:"çift_bloklar.12."},double_blocks_13_:{name:"çift_bloklar.13."},double_blocks_14_:{name:"çift_bloklar.14."},double_blocks_15_:{name:"çift_bloklar.15."},double_blocks_16_:{name:"çift_bloklar.16."},double_blocks_17_:{name:"çift_bloklar.17."},double_blocks_18_:{name:"çift_bloklar.18."},double_blocks_1_:{name:"çift_bloklar.1."},double_blocks_2_:{name:"çift_bloklar.2."},double_blocks_3_:{name:"çift_bloklar.3."},double_blocks_4_:{name:"çift_bloklar.4."},double_blocks_5_:{name:"çift_bloklar.5."},double_blocks_6_:{name:"çift_bloklar.6."},double_blocks_7_:{name:"çift_bloklar.7."},double_blocks_8_:{name:"çift_bloklar.8."},double_blocks_9_:{name:"çift_bloklar.9."},final_layer_:{name:"son_katman."},guidance_in:{name:"rehberlik_girişi"},img_in_:{name:"görüntü_girişi."},model1:{name:"model1"},model2:{name:"model2"},single_blocks_0_:{name:"tek_bloklar.0."},single_blocks_10_:{name:"tek_bloklar.10."},single_blocks_11_:{name:"tek_bloklar.11."},single_blocks_12_:{name:"tek_bloklar.12."},single_blocks_13_:{name:"tek_bloklar.13."},single_blocks_14_:{name:"tek_bloklar.14."},single_blocks_15_:{name:"tek_bloklar.15."},single_blocks_16_:{name:"tek_bloklar.16."},single_blocks_17_:{name:"tek_bloklar.17."},single_blocks_18_:{name:"tek_bloklar.18."},single_blocks_19_:{name:"tek_bloklar.19."},single_blocks_1_:{name:"tek_bloklar.1."},single_blocks_20_:{name:"tek_bloklar.20."},single_blocks_21_:{name:"tek_bloklar.21."},single_blocks_22_:{name:"tek_bloklar.22."},single_blocks_23_:{name:"tek_bloklar.23."},single_blocks_24_:{name:"tek_bloklar.24."},single_blocks_25_:{name:"tek_bloklar.25."},single_blocks_26_:{name:"tek_bloklar.26."},single_blocks_27_:{name:"tek_bloklar.27."},single_blocks_28_:{name:"tek_bloklar.28."},single_blocks_29_:{name:"tek_bloklar.29."},single_blocks_2_:{name:"tek_bloklar.2."},single_blocks_30_:{name:"tek_bloklar.30."},single_blocks_31_:{name:"tek_bloklar.31."},single_blocks_32_:{name:"tek_bloklar.32."},single_blocks_33_:{name:"tek_bloklar.33."},single_blocks_34_:{name:"tek_bloklar.34."},single_blocks_35_:{name:"tek_bloklar.35."},single_blocks_36_:{name:"tek_bloklar.36."},single_blocks_37_:{name:"tek_bloklar.37."},single_blocks_3_:{name:"tek_bloklar.3."},single_blocks_4_:{name:"tek_bloklar.4."},single_blocks_5_:{name:"tek_bloklar.5."},single_blocks_6_:{name:"tek_bloklar.6."},single_blocks_7_:{name:"tek_bloklar.7."},single_blocks_8_:{name:"tek_bloklar.8."},single_blocks_9_:{name:"tek_bloklar.9."},time_in_:{name:"zaman_girişi."},txt_in_:{name:"metin_girişi."},vector_in_:{name:"vektör_girişi."}}},Fn={display_name:"ModelBirleştirmeLTXV",inputs:{adaln_single_:{name:"adaln_tek."},caption_projection_:{name:"başlık_projeksiyonu."},model1:{name:"model1"},model2:{name:"model2"},patchify_proj_:{name:"yama_proj."},proj_out_:{name:"proj_çıkışı."},scale_shift_table:{name:"ölçek_kaydırma_tablosu"},transformer_blocks_0_:{name:"dönüştürücü_blokları.0."},transformer_blocks_10_:{name:"dönüştürücü_blokları.10."},transformer_blocks_11_:{name:"dönüştürücü_blokları.11."},transformer_blocks_12_:{name:"dönüştürücü_blokları.12."},transformer_blocks_13_:{name:"dönüştürücü_blokları.13."},transformer_blocks_14_:{name:"dönüştürücü_blokları.14."},transformer_blocks_15_:{name:"dönüştürücü_blokları.15."},transformer_blocks_16_:{name:"dönüştürücü_blokları.16."},transformer_blocks_17_:{name:"dönüştürücü_blokları.17."},transformer_blocks_18_:{name:"dönüştürücü_blokları.18."},transformer_blocks_19_:{name:"dönüştürücü_blokları.19."},transformer_blocks_1_:{name:"dönüştürücü_blokları.1."},transformer_blocks_20_:{name:"dönüştürücü_blokları.20."},transformer_blocks_21_:{name:"dönüştürücü_blokları.21."},transformer_blocks_22_:{name:"dönüştürücü_blokları.22."},transformer_blocks_23_:{name:"dönüştürücü_blokları.23."},transformer_blocks_24_:{name:"dönüştürücü_blokları.24."},transformer_blocks_25_:{name:"dönüştürücü_blokları.25."},transformer_blocks_26_:{name:"dönüştürücü_blokları.26."},transformer_blocks_27_:{name:"dönüştürücü_blokları.27."},transformer_blocks_2_:{name:"dönüştürücü_blokları.2."},transformer_blocks_3_:{name:"dönüştürücü_blokları.3."},transformer_blocks_4_:{name:"dönüştürücü_blokları.4."},transformer_blocks_5_:{name:"dönüştürücü_blokları.5."},transformer_blocks_6_:{name:"dönüştürücü_blokları.6."},transformer_blocks_7_:{name:"dönüştürücü_blokları.7."},transformer_blocks_8_:{name:"dönüştürücü_blokları.8."},transformer_blocks_9_:{name:"dönüştürücü_blokları.9."}}},Un={display_name:"ModelBirleştirmeMochiÖnizleme",inputs:{blocks_0_:{name:"bloklar.0."},blocks_10_:{name:"bloklar.10."},blocks_11_:{name:"bloklar.11."},blocks_12_:{name:"bloklar.12."},blocks_13_:{name:"bloklar.13."},blocks_14_:{name:"bloklar.14."},blocks_15_:{name:"bloklar.15."},blocks_16_:{name:"bloklar.16."},blocks_17_:{name:"bloklar.17."},blocks_18_:{name:"bloklar.18."},blocks_19_:{name:"bloklar.19."},blocks_1_:{name:"bloklar.1."},blocks_20_:{name:"bloklar.20."},blocks_21_:{name:"bloklar.21."},blocks_22_:{name:"bloklar.22."},blocks_23_:{name:"bloklar.23."},blocks_24_:{name:"bloklar.24."},blocks_25_:{name:"bloklar.25."},blocks_26_:{name:"bloklar.26."},blocks_27_:{name:"bloklar.27."},blocks_28_:{name:"bloklar.28."},blocks_29_:{name:"bloklar.29."},blocks_2_:{name:"bloklar.2."},blocks_30_:{name:"bloklar.30."},blocks_31_:{name:"bloklar.31."},blocks_32_:{name:"bloklar.32."},blocks_33_:{name:"bloklar.33."},blocks_34_:{name:"bloklar.34."},blocks_35_:{name:"bloklar.35."},blocks_36_:{name:"bloklar.36."},blocks_37_:{name:"bloklar.37."},blocks_38_:{name:"bloklar.38."},blocks_39_:{name:"bloklar.39."},blocks_3_:{name:"bloklar.3."},blocks_40_:{name:"bloklar.40."},blocks_41_:{name:"bloklar.41."},blocks_42_:{name:"bloklar.42."},blocks_43_:{name:"bloklar.43."},blocks_44_:{name:"bloklar.44."},blocks_45_:{name:"bloklar.45."},blocks_46_:{name:"bloklar.46."},blocks_47_:{name:"bloklar.47."},blocks_4_:{name:"bloklar.4."},blocks_5_:{name:"bloklar.5."},blocks_6_:{name:"bloklar.6."},blocks_7_:{name:"bloklar.7."},blocks_8_:{name:"bloklar.8."},blocks_9_:{name:"bloklar.9."},final_layer_:{name:"son_katman."},model1:{name:"model1"},model2:{name:"model2"},pos_frequencies_:{name:"konum_frekansları."},t5_y_embedder_:{name:"t5_y_gömücü."},t5_yproj_:{name:"t5_yproj."},t_embedder_:{name:"t_gömücü."}}},wn={display_name:"ModelBirleştirmeSD1",inputs:{input_blocks_0_:{name:"giriş_blokları.0."},input_blocks_10_:{name:"giriş_blokları.10."},input_blocks_11_:{name:"giriş_blokları.11."},input_blocks_1_:{name:"giriş_blokları.1."},input_blocks_2_:{name:"giriş_blokları.2."},input_blocks_3_:{name:"giriş_blokları.3."},input_blocks_4_:{name:"giriş_blokları.4."},input_blocks_5_:{name:"giriş_blokları.5."},input_blocks_6_:{name:"giriş_blokları.6."},input_blocks_7_:{name:"giriş_blokları.7."},input_blocks_8_:{name:"giriş_blokları.8."},input_blocks_9_:{name:"giriş_blokları.9."},label_emb_:{name:"etiket_gömme."},middle_block_0_:{name:"orta_blok.0."},middle_block_1_:{name:"orta_blok.1."},middle_block_2_:{name:"orta_blok.2."},model1:{name:"model1"},model2:{name:"model2"},out_:{name:"çıktı."},output_blocks_0_:{name:"çıktı_blokları.0."},output_blocks_10_:{name:"çıktı_blokları.10."},output_blocks_11_:{name:"çıktı_blokları.11."},output_blocks_1_:{name:"çıktı_blokları.1."},output_blocks_2_:{name:"çıktı_blokları.2."},output_blocks_3_:{name:"çıktı_blokları.3."},output_blocks_4_:{name:"çıktı_blokları.4."},output_blocks_5_:{name:"çıktı_blokları.5."},output_blocks_6_:{name:"çıktı_blokları.6."},output_blocks_7_:{name:"çıktı_blokları.7."},output_blocks_8_:{name:"çıktı_blokları.8."},output_blocks_9_:{name:"çıktı_blokları.9."},time_embed_:{name:"zaman_gömme."}}},On={display_name:"ModelBirleştirmeSD2",inputs:{input_blocks_0_:{name:"giriş_blokları.0."},input_blocks_10_:{name:"giriş_blokları.10."},input_blocks_11_:{name:"giriş_blokları.11."},input_blocks_1_:{name:"giriş_blokları.1."},input_blocks_2_:{name:"giriş_blokları.2."},input_blocks_3_:{name:"giriş_blokları.3."},input_blocks_4_:{name:"giriş_blokları.4."},input_blocks_5_:{name:"giriş_blokları.5."},input_blocks_6_:{name:"giriş_blokları.6."},input_blocks_7_:{name:"giriş_blokları.7."},input_blocks_8_:{name:"giriş_blokları.8."},input_blocks_9_:{name:"giriş_blokları.9."},label_emb_:{name:"etiket_gömme."},middle_block_0_:{name:"orta_blok.0."},middle_block_1_:{name:"orta_blok.1."},middle_block_2_:{name:"orta_blok.2."},model1:{name:"model1"},model2:{name:"model2"},out_:{name:"çıktı."},output_blocks_0_:{name:"çıktı_blokları.0."},output_blocks_10_:{name:"çıktı_blokları.10."},output_blocks_11_:{name:"çıktı_blokları.11."},output_blocks_1_:{name:"çıktı_blokları.1."},output_blocks_2_:{name:"çıktı_blokları.2."},output_blocks_3_:{name:"çıktı_blokları.3."},output_blocks_4_:{name:"çıktı_blokları.4."},output_blocks_5_:{name:"çıktı_blokları.5."},output_blocks_6_:{name:"çıktı_blokları.6."},output_blocks_7_:{name:"çıktı_blokları.7."},output_blocks_8_:{name:"çıktı_blokları.8."},output_blocks_9_:{name:"çıktı_blokları.9."},time_embed_:{name:"zaman_gömme."}}},jn={display_name:"ModelBirleştirmeSD35_Büyük",inputs:{context_embedder_:{name:"bağlam_gömücü."},final_layer_:{name:"son_katman."},joint_blocks_0_:{name:"birleşik_bloklar.0."},joint_blocks_10_:{name:"birleşik_bloklar.10."},joint_blocks_11_:{name:"birleşik_bloklar.11."},joint_blocks_12_:{name:"birleşik_bloklar.12."},joint_blocks_13_:{name:"birleşik_bloklar.13."},joint_blocks_14_:{name:"birleşik_bloklar.14."},joint_blocks_15_:{name:"birleşik_bloklar.15."},joint_blocks_16_:{name:"birleşik_bloklar.16."},joint_blocks_17_:{name:"birleşik_bloklar.17."},joint_blocks_18_:{name:"birleşik_bloklar.18."},joint_blocks_19_:{name:"birleşik_bloklar.19."},joint_blocks_1_:{name:"birleşik_bloklar.1."},joint_blocks_20_:{name:"birleşik_bloklar.20."},joint_blocks_21_:{name:"birleşik_bloklar.21."},joint_blocks_22_:{name:"birleşik_bloklar.22."},joint_blocks_23_:{name:"birleşik_bloklar.23."},joint_blocks_24_:{name:"birleşik_bloklar.24."},joint_blocks_25_:{name:"birleşik_bloklar.25."},joint_blocks_26_:{name:"birleşik_bloklar.26."},joint_blocks_27_:{name:"birleşik_bloklar.27."},joint_blocks_28_:{name:"birleşik_bloklar.28."},joint_blocks_29_:{name:"birleşik_bloklar.29."},joint_blocks_2_:{name:"birleşik_bloklar.2."},joint_blocks_30_:{name:"birleşik_bloklar.30."},joint_blocks_31_:{name:"birleşik_bloklar.31."},joint_blocks_32_:{name:"birleşik_bloklar.32."},joint_blocks_33_:{name:"birleşik_bloklar.33."},joint_blocks_34_:{name:"birleşik_bloklar.34."},joint_blocks_35_:{name:"birleşik_bloklar.35."},joint_blocks_36_:{name:"birleşik_bloklar.36."},joint_blocks_37_:{name:"birleşik_bloklar.37."},joint_blocks_3_:{name:"birleşik_bloklar.3."},joint_blocks_4_:{name:"birleşik_bloklar.4."},joint_blocks_5_:{name:"birleşik_bloklar.5."},joint_blocks_6_:{name:"birleşik_bloklar.6."},joint_blocks_7_:{name:"birleşik_bloklar.7."},joint_blocks_8_:{name:"birleşik_bloklar.8."},joint_blocks_9_:{name:"birleşik_bloklar.9."},model1:{name:"model1"},model2:{name:"model2"},pos_embed_:{name:"konum_gömme."},t_embedder_:{name:"t_gömücü."},x_embedder_:{name:"x_gömücü."},y_embedder_:{name:"y_gömücü."}}},Hn={display_name:"ModelBirleştirmeSD3_2B",inputs:{context_embedder_:{name:"bağlam_gömücü."},final_layer_:{name:"son_katman."},joint_blocks_0_:{name:"birleşik_bloklar.0."},joint_blocks_10_:{name:"birleşik_bloklar.10."},joint_blocks_11_:{name:"birleşik_bloklar.11."},joint_blocks_12_:{name:"birleşik_bloklar.12."},joint_blocks_13_:{name:"birleşik_bloklar.13."},joint_blocks_14_:{name:"birleşik_bloklar.14."},joint_blocks_15_:{name:"birleşik_bloklar.15."},joint_blocks_16_:{name:"birleşik_bloklar.16."},joint_blocks_17_:{name:"birleşik_bloklar.17."},joint_blocks_18_:{name:"birleşik_bloklar.18."},joint_blocks_19_:{name:"birleşik_bloklar.19."},joint_blocks_1_:{name:"birleşik_bloklar.1."},joint_blocks_20_:{name:"birleşik_bloklar.20."},joint_blocks_21_:{name:"birleşik_bloklar.21."},joint_blocks_22_:{name:"birleşik_bloklar.22."},joint_blocks_23_:{name:"birleşik_bloklar.23."},joint_blocks_2_:{name:"birleşik_bloklar.2."},joint_blocks_3_:{name:"birleşik_bloklar.3."},joint_blocks_4_:{name:"birleşik_bloklar.4."},joint_blocks_5_:{name:"birleşik_bloklar.5."},joint_blocks_6_:{name:"birleşik_bloklar.6."},joint_blocks_7_:{name:"birleşik_bloklar.7."},joint_blocks_8_:{name:"birleşik_bloklar.8."},joint_blocks_9_:{name:"birleşik_bloklar.9."},model1:{name:"model1"},model2:{name:"model2"},pos_embed_:{name:"konum_gömme."},t_embedder_:{name:"t_gömücü."},x_embedder_:{name:"x_gömücü."},y_embedder_:{name:"y_gömücü."}}},Yn={display_name:"ModelBirleştirmeSDXL",inputs:{input_blocks_0:{name:"giriş_blokları.0"},input_blocks_1:{name:"giriş_blokları.1"},input_blocks_2:{name:"giriş_blokları.2"},input_blocks_3:{name:"giriş_blokları.3"},input_blocks_4:{name:"giriş_blokları.4"},input_blocks_5:{name:"giriş_blokları.5"},input_blocks_6:{name:"giriş_blokları.6"},input_blocks_7:{name:"giriş_blokları.7"},input_blocks_8:{name:"giriş_blokları.8"},label_emb_:{name:"etiket_gömme."},middle_block_0:{name:"orta_blok.0"},middle_block_1:{name:"orta_blok.1"},middle_block_2:{name:"orta_blok.2"},model1:{name:"model1"},model2:{name:"model2"},out_:{name:"çıktı."},output_blocks_0:{name:"çıktı_blokları.0"},output_blocks_1:{name:"çıktı_blokları.1"},output_blocks_2:{name:"çıktı_blokları.2"},output_blocks_3:{name:"çıktı_blokları.3"},output_blocks_4:{name:"çıktı_blokları.4"},output_blocks_5:{name:"çıktı_blokları.5"},output_blocks_6:{name:"çıktı_blokları.6"},output_blocks_7:{name:"çıktı_blokları.7"},output_blocks_8:{name:"çıktı_blokları.8"},time_embed_:{name:"zaman_gömme."}}},Wn={display_name:"BasitModelBirleştirme",inputs:{model1:{name:"model1"},model2:{name:"model2"},ratio:{name:"oran"}}},Xn={display_name:"ModelBirleştirmeÇıkarma",inputs:{model1:{name:"model1"},model2:{name:"model2"},multiplier:{name:"çarpan"}}},Zn={description:"1.3B modelinde 30 blok, 14B modelinde 40 blok bulunur. Görüntüden videoya modelinde ek olarak img_emb bulunur.",display_name:"ModelBirleştirmeWAN2_1",inputs:{blocks_0_:{name:"bloklar.0."},blocks_10_:{name:"bloklar.10."},blocks_11_:{name:"bloklar.11."},blocks_12_:{name:"bloklar.12."},blocks_13_:{name:"bloklar.13."},blocks_14_:{name:"bloklar.14."},blocks_15_:{name:"bloklar.15."},blocks_16_:{name:"bloklar.16."},blocks_17_:{name:"bloklar.17."},blocks_18_:{name:"bloklar.18."},blocks_19_:{name:"bloklar.19."},blocks_1_:{name:"bloklar.1."},blocks_20_:{name:"bloklar.20."},blocks_21_:{name:"bloklar.21."},blocks_22_:{name:"bloklar.22."},blocks_23_:{name:"bloklar.23."},blocks_24_:{name:"bloklar.24."},blocks_25_:{name:"bloklar.25."},blocks_26_:{name:"bloklar.26."},blocks_27_:{name:"bloklar.27."},blocks_28_:{name:"bloklar.28."},blocks_29_:{name:"bloklar.29."},blocks_2_:{name:"bloklar.2."},blocks_30_:{name:"bloklar.30."},blocks_31_:{name:"bloklar.31."},blocks_32_:{name:"bloklar.32."},blocks_33_:{name:"bloklar.33."},blocks_34_:{name:"bloklar.34."},blocks_35_:{name:"bloklar.35."},blocks_36_:{name:"bloklar.36."},blocks_37_:{name:"bloklar.37."},blocks_38_:{name:"bloklar.38."},blocks_39_:{name:"bloklar.39."},blocks_3_:{name:"bloklar.3."},blocks_4_:{name:"bloklar.4."},blocks_5_:{name:"bloklar.5."},blocks_6_:{name:"bloklar.6."},blocks_7_:{name:"bloklar.7."},blocks_8_:{name:"bloklar.8."},blocks_9_:{name:"bloklar.9."},head_:{name:"baş."},img_emb_:{name:"görüntü_gömme."},model1:{name:"model1"},model2:{name:"model2"},patch_embedding_:{name:"yama_gömme."},text_embedding_:{name:"metin_gömme."},time_embedding_:{name:"zaman_gömme."},time_projection_:{name:"zaman_projeksiyonu."}}},qn={display_name:"ModelÖrneklemeAuraFlow",inputs:{model:{name:"model"},shift:{name:"kaydırma"}}},Qn={display_name:"ModelÖrneklemeSürekliEDM",inputs:{model:{name:"model"},sampling:{name:"örnekleme"},sigma_max:{name:"sigma_maks"},sigma_min:{name:"sigma_min"}}},Jn={display_name:"ModelÖrneklemeSürekliV",inputs:{model:{name:"model"},sampling:{name:"örnekleme"},sigma_max:{name:"sigma_maks"},sigma_min:{name:"sigma_min"}}},$n={display_name:"ModelÖrneklemeAyrık",inputs:{model:{name:"model"},sampling:{name:"örnekleme"},zsnr:{name:"zsnr"}}},ei={display_name:"ModelÖrneklemeFlux",inputs:{base_shift:{name:"temel_kaydırma"},height:{name:"yükseklik"},max_shift:{name:"maks_kaydırma"},model:{name:"model"},width:{name:"genişlik"}}},ai={display_name:"ModelÖrneklemeLTXV",inputs:{base_shift:{name:"temel_kaydırma"},latent:{name:"gizli"},max_shift:{name:"maks_kaydırma"},model:{name:"model"}}},ni={display_name:"ModelÖrneklemeSD3",inputs:{model:{name:"model"},shift:{name:"kaydırma"}}},ii={display_name:"ModelÖrneklemeStabilKaskad",inputs:{model:{name:"model"},shift:{name:"kaydırma"}}},li={display_name:"ModelKaydet",inputs:{filename_prefix:{name:"dosyaadı_öneki"},model:{name:"model"}}},ti={display_name:"GörüntüMorfolojisi",inputs:{image:{name:"görüntü"},kernel_size:{name:"çekirdek_boyutu"},operation:{name:"işlem"}}},oi={description:"OpenAI'nin DALL·E 2 uç noktası aracılığıyla eşzamanlı olarak görüntüler oluşturur.",display_name:"OpenAI DALL·E 2",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü",tooltip:"Görüntü düzenleme için isteğe bağlı referans görüntü."},mask:{name:"maske",tooltip:"İç boyama için isteğe bağlı maske (beyaz alanlar değiştirilecektir)"},n:{name:"n",tooltip:"Kaç tane görüntü oluşturulacağı"},prompt:{name:"istem",tooltip:"DALL·E için metin istemi"},seed:{name:"tohum",tooltip:"arka uçta henüz uygulanmadı"},size:{name:"boyut",tooltip:"Görüntü boyutu"}}},mi={description:"OpenAI'nin DALL·E 3 uç noktası aracılığıyla eşzamanlı olarak görüntüler oluşturur.",display_name:"OpenAI DALL·E 3",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},prompt:{name:"istem",tooltip:"DALL·E için metin istemi"},quality:{name:"kalite",tooltip:"Görüntü kalitesi"},seed:{name:"tohum",tooltip:"arka uçta henüz uygulanmadı"},size:{name:"boyut",tooltip:"Görüntü boyutu"},style:{name:"stil",tooltip:"Canlı, modelin hiper-gerçekçi ve dramatik görüntüler oluşturmaya yönelmesine neden olur. Doğal, modelin daha doğal, daha az hiper-gerçekçi görünen görüntüler üretmesine neden olur."}}},ri={description:"OpenAI'nin GPT Görüntü 1 uç noktası aracılığıyla eşzamanlı olarak görüntüler oluşturur.",display_name:"OpenAI GPT Görüntü 1",inputs:{background:{name:"arka_plan",tooltip:"Görüntüyü arka planlı veya arka plansız döndür"},control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü",tooltip:"Görüntü düzenleme için isteğe bağlı referans görüntü."},mask:{name:"maske",tooltip:"İç boyama için isteğe bağlı maske (beyaz alanlar değiştirilecektir)"},n:{name:"n",tooltip:"Kaç tane görüntü oluşturulacağı"},prompt:{name:"istem",tooltip:"GPT Görüntü 1 için metin istemi"},quality:{name:"kalite",tooltip:"Görüntü kalitesi, maliyeti ve üretim süresini etkiler."},seed:{name:"tohum",tooltip:"arka uçta henüz uygulanmadı"},size:{name:"boyut",tooltip:"Görüntü boyutu"}}},si={display_name:"OptimalAdımlarZamanlayıcı",inputs:{denoise:{name:"gürültü_azaltma"},model_type:{name:"model_türü"},steps:{name:"adımlar"}}},_i={display_name:"Koşul Çifti Birleştir",inputs:{negative_A:{name:"negatif_A"},negative_B:{name:"negatif_B"},positive_A:{name:"pozitif_A"},positive_B:{name:"pozitif_B"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"}}},ki={display_name:"Koşul Çifti Varsayılan Birleştirmeyi Ayarla",inputs:{hooks:{name:"kancalar"},negative:{name:"negatif"},negative_DEFAULT:{name:"negatif_VARSAYILAN"},positive:{name:"pozitif"},positive_DEFAULT:{name:"pozitif_VARSAYILAN"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"}}},di={display_name:"Koşul Çifti Özelliklerini Ayarla",inputs:{hooks:{name:"kancalar"},mask:{name:"maske"},negative_NEW:{name:"yeni_negatif"},positive_NEW:{name:"yeni_pozitif"},set_cond_area:{name:"koşul_alanı_ayarla"},strength:{name:"güç"},timesteps:{name:"zaman_adımları"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"}}},pi={display_name:"Koşul Çifti Özelliklerini Ayarla ve Birleştir",inputs:{hooks:{name:"kancalar"},mask:{name:"maske"},negative:{name:"negatif"},negative_NEW:{name:"yeni_negatif"},positive:{name:"pozitif"},positive_NEW:{name:"yeni_pozitif"},set_cond_area:{name:"koşul_alanı_ayarla"},strength:{name:"güç"},timesteps:{name:"zaman_adımları"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"}}},ui={display_name:"Model Yaması Ekle Küçültme (Kohya Deep Shrink)",inputs:{block_number:{name:"blok_numarası"},downscale_after_skip:{name:"atlamadan_sonra_küçült"},downscale_factor:{name:"küçültme_faktörü"},downscale_method:{name:"küçültme_yöntemi"},end_percent:{name:"bitiş_yüzdesi"},model:{name:"model"},start_percent:{name:"başlangıç_yüzdesi"},upscale_method:{name:"büyütme_yöntemi"}}},ci={display_name:"Perp-Neg (PerpNegGuider tarafından ESKİ)",inputs:{empty_conditioning:{name:"boş_koşullandırma"},model:{name:"model"},neg_scale:{name:"neg_ölçek"}}},gi={display_name:"PerpNegRehberi",inputs:{cfg:{name:"cfg"},empty_conditioning:{name:"boş_koşullandırma"},model:{name:"model"},neg_scale:{name:"neg_ölçek"},negative:{name:"negatif"},positive:{name:"pozitif"}}},bi={display_name:"BozulmuşDikkatRehberliği",inputs:{model:{name:"model"},scale:{name:"ölçek"}}},yi={display_name:"PhotoMakerKodlama",inputs:{clip:{name:"clip"},image:{name:"görüntü"},photomaker:{name:"photomaker"},text:{name:"metin"}}},fi={display_name:"PhotoMakerYükleyici",inputs:{photomaker_model_name:{name:"photomaker_model_adı"}}},hi={description:"Bir video oluşturmak için Pika API v2.2'ye bir görüntü ve istem gönderir.",display_name:"Pika Görüntüden Videoya",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},duration:{name:"süre"},image:{name:"görüntü",tooltip:"Videoya dönüştürülecek görüntü"},negative_prompt:{name:"negatif_istem"},prompt_text:{name:"istem_metni"},resolution:{name:"çözünürlük"},seed:{name:"tohum"}}},zi={description:"İçlerindeki nesnelerle bir video oluşturmak için görüntülerinizi birleştirin. Malzeme olarak birden fazla görüntü yükleyin ve hepsini içeren yüksek kaliteli bir video oluşturun.",display_name:"Pika Sahneleri (Video Görüntü Kompozisyonu)",inputs:{aspect_ratio:{name:"en_boy_oranı",tooltip:"En boy oranı (genişlik / yükseklik)"},control_after_generate:{name:"oluşturduktan sonra kontrol et"},duration:{name:"süre"},image_ingredient_1:{name:"görüntü_malzemesi_1",tooltip:"Video oluşturmak için malzeme olarak kullanılacak görüntü."},image_ingredient_2:{name:"görüntü_malzemesi_2",tooltip:"Video oluşturmak için malzeme olarak kullanılacak görüntü."},image_ingredient_3:{name:"görüntü_malzemesi_3",tooltip:"Video oluşturmak için malzeme olarak kullanılacak görüntü."},image_ingredient_4:{name:"görüntü_malzemesi_4",tooltip:"Video oluşturmak için malzeme olarak kullanılacak görüntü."},image_ingredient_5:{name:"görüntü_malzemesi_5",tooltip:"Video oluşturmak için malzeme olarak kullanılacak görüntü."},ingredients_mode:{name:"malzemeler_modu"},negative_prompt:{name:"negatif_istem"},prompt_text:{name:"istem_metni"},resolution:{name:"çözünürlük"},seed:{name:"tohum"}}},vi={description:"İlk ve son karenizi birleştirerek bir video oluşturun. Başlangıç ve bitiş noktalarını tanımlamak için iki görüntü yükleyin ve yapay zekanın aralarında pürüzsüz bir geçiş oluşturmasına izin verin.",display_name:"Pika Başlangıç ve Bitiş Karesinden Videoya",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},duration:{name:"süre"},image_end:{name:"bitiş_görüntüsü",tooltip:"Birleştirilecek son görüntü."},image_start:{name:"başlangıç_görüntüsü",tooltip:"Birleştirilecek ilk görüntü."},negative_prompt:{name:"negatif_istem"},prompt_text:{name:"istem_metni"},resolution:{name:"çözünürlük"},seed:{name:"tohum"}}},Si={description:"Bir video oluşturmak için Pika API v2.2'ye bir metin istemi gönderir.",display_name:"Pika Metinden Videoya",inputs:{aspect_ratio:{name:"en_boy_oranı",tooltip:"En boy oranı (genişlik / yükseklik)"},control_after_generate:{name:"oluşturduktan sonra kontrol et"},duration:{name:"süre"},negative_prompt:{name:"negatif_istem"},prompt_text:{name:"istem_metni"},resolution:{name:"çözünürlük"},seed:{name:"tohum"}}},Li={description:"Videonuzun içine herhangi bir nesne veya görüntü ekleyin. Bir video yükleyin ve sorunsuz bir şekilde entegre edilmiş bir sonuç oluşturmak için ne eklemek istediğinizi belirtin.",display_name:"Pikadditions (Video Nesne Ekleme)",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü",tooltip:"Videoya eklenecek görüntü."},negative_prompt:{name:"negatif_istem"},prompt_text:{name:"istem_metni"},seed:{name:"tohum"},video:{name:"video",tooltip:"Görüntü eklenecek video."}}},Ci={description:"Belirli bir Pikaffect ile bir video oluşturun. Desteklenen Pikaffect'ler: Cake-ify, Crumble, Crush, Decapitate, Deflate, Dissolve, Explode, Eye-pop, Inflate, Levitate, Melt, Peel, Poke, Squish, Ta-da, Tear",display_name:"Pikaffects (Video Efektleri)",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü",tooltip:"Pikaffect'in uygulanacağı referans görüntü."},negative_prompt:{name:"negatif_istem"},pikaffect:{name:"pikaffect"},prompt_text:{name:"istem_metni"},seed:{name:"tohum"}}},Mi={description:"Videonuzdaki herhangi bir nesneyi veya bölgeyi yeni bir görüntü veya nesneyle değiştirin. Değiştirilecek alanları bir maske veya koordinatlarla tanımlayın.",display_name:"Pika Değişimleri (Video Nesne Değiştirme)",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü",tooltip:"Videodaki maskelenmiş nesneyi değiştirmek için kullanılan görüntü."},mask:{name:"maske",tooltip:"Videoda değiştirilecek alanları tanımlamak için maskeyi kullanın"},negative_prompt:{name:"negatif_istem"},prompt_text:{name:"istem_metni"},seed:{name:"tohum"},video:{name:"video",tooltip:"İçinde bir nesne değiştirilecek video."}}},Gi={description:"İstem ve çıktı_boyutuna göre videoları eşzamanlı olarak oluşturur.",display_name:"PixVerse Görüntüden Videoya",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},duration_seconds:{name:"süre_saniye"},image:{name:"görüntü"},motion_mode:{name:"hareket_modu"},negative_prompt:{name:"negatif_istem",tooltip:"Bir görüntüde istenmeyen öğelerin isteğe bağlı metin açıklaması."},pixverse_template:{name:"pixverse_şablonu",tooltip:"PixVerse Şablon düğümü tarafından oluşturulan, üretimin stilini etkilemek için isteğe bağlı bir şablon."},prompt:{name:"istem",tooltip:"Video oluşturma istemi"},quality:{name:"kalite"},seed:{name:"tohum",tooltip:"Video oluşturma için tohum."}}},Vi={display_name:"PixVerse Şablonu",inputs:{template:{name:"şablon"}},outputs:{0:{name:"pixverse_şablonu"}}},Ii={description:"İstem ve çıktı_boyutuna göre videoları eşzamanlı olarak oluşturur.",display_name:"PixVerse Metinden Videoya",inputs:{aspect_ratio:{name:"en_boy_oranı"},control_after_generate:{name:"oluşturduktan sonra kontrol et"},duration_seconds:{name:"süre_saniye"},motion_mode:{name:"hareket_modu"},negative_prompt:{name:"negatif_istem",tooltip:"Bir görüntüde istenmeyen öğelerin isteğe bağlı metin açıklaması."},pixverse_template:{name:"pixverse_şablonu",tooltip:"PixVerse Şablon düğümü tarafından oluşturulan, üretimin stilini etkilemek için isteğe bağlı bir şablon."},prompt:{name:"istem",tooltip:"Video oluşturma istemi"},quality:{name:"kalite"},seed:{name:"tohum",tooltip:"Video oluşturma için tohum."}}},Ai={description:"İstem ve çıktı_boyutuna göre videoları eşzamanlı olarak oluşturur.",display_name:"PixVerse Geçiş Videosu",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},duration_seconds:{name:"süre_saniye"},first_frame:{name:"ilk_kare"},last_frame:{name:"son_kare"},motion_mode:{name:"hareket_modu"},negative_prompt:{name:"negatif_istem",tooltip:"Bir görüntüde istenmeyen öğelerin isteğe bağlı metin açıklaması."},prompt:{name:"istem",tooltip:"Video oluşturma istemi"},quality:{name:"kalite"},seed:{name:"tohum",tooltip:"Video oluşturma için tohum."}}},Pi={display_name:"ÇokÜstelZamanlayıcı",inputs:{rho:{name:"rho"},sigma_max:{name:"sigma_maks"},sigma_min:{name:"sigma_min"},steps:{name:"adımlar"}}},Di={display_name:"Porter-Duff Görüntü Birleştirme",inputs:{destination:{name:"hedef"},destination_alpha:{name:"hedef_alfa"},mode:{name:"mod"},source:{name:"kaynak"},source_alpha:{name:"kaynak_alfa"}}},Ki={display_name:"3D Önizleme",inputs:{camera_info:{name:"kamera_bilgisi"},image:{name:"görüntü"},model_file:{name:"model_dosyası"}}},xi={display_name:"3D Önizleme - Animasyon",inputs:{camera_info:{name:"kamera_bilgisi"},model_file:{name:"model_dosyası"}}},Bi={display_name:"Herhangi Bir Şeyi Önizle",inputs:{preview:{},source:{name:"kaynak"}}},Ti={display_name:"Sesi Önizle",inputs:{audio:{name:"ses"},audioUI:{name:"sesArayüzü"}}},Ei={description:"Giriş görüntülerini ComfyUI çıktı dizininize kaydeder.",display_name:"Görüntüyü Önizle",inputs:{images:{name:"görüntüler"}}},Ni={display_name:"Boolean",inputs:{value:{name:"değer"}}},Ri={display_name:"Float",inputs:{value:{name:"değer"}}},Fi={display_name:"Int",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},value:{name:"değer"}}},Ui={display_name:"String",inputs:{value:{name:"değer"}}},wi={display_name:"String (Çok Satırlı)",inputs:{value:{name:"değer"}}},Oi={description:`[Tarifler]

hidream: uzun clip-l, uzun clip-g, t5xxl, llama_8b_3.1_instruct`,display_name:"DörtlüCLIPYükleyici",inputs:{clip_name1:{name:"clip_adı1"},clip_name2:{name:"clip_adı2"},clip_name3:{name:"clip_adı3"},clip_name4:{name:"clip_adı4"}}},ji={display_name:"RastgeleGürültü",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},noise_seed:{name:"gürültü_tohumu"}}},Hi={display_name:"Görüntüleri Yeniden Grupla",inputs:{batch_size:{name:"toplu_boyut"},images:{name:"görüntüler"}}},Yi={display_name:"Gizli Değişkenleri Yeniden Grupla",inputs:{batch_size:{name:"toplu_boyut"},latents:{name:"gizli_değişkenler"}}},Wi={description:"Belirli RGB değerlerini seçerek Recraft Rengi oluşturun.",display_name:"Recraft Renk RGB",inputs:{b:{name:"m",tooltip:"Rengin Mavi değeri."},g:{name:"y",tooltip:"Rengin Yeşil değeri."},r:{name:"k",tooltip:"Rengin Kırmızı değeri."},recraft_color:{name:"recraft_rengi"}},outputs:{0:{name:"recraft_rengi"}}},Xi={description:"Recraft üretimini özelleştirmek için Recraft Kontrolleri oluşturun.",display_name:"Recraft Kontrolleri",inputs:{background_color:{name:"arka_plan_rengi"},colors:{name:"renkler"}},outputs:{0:{name:"recraft_kontrolleri"}}},Zi={description:`Görüntüyü eşzamanlı olarak büyütün.
Verilen bir raster görüntüyü ‘yaratıcı büyütme’ aracıyla geliştirir, küçük ayrıntıları ve yüzleri iyileştirmeye odaklanarak çözünürlüğü artırır.`,display_name:"Recraft Yaratıcı Büyütme Görüntüsü",inputs:{image:{name:"görüntü"}}},qi={description:`Görüntüyü eşzamanlı olarak büyütün.
Verilen bir raster görüntüyü ‘net büyütme’ aracıyla geliştirir, görüntü çözünürlüğünü artırır, görüntüyü daha keskin ve temiz hale getirir.`,display_name:"Recraft Net Büyütme Görüntüsü",inputs:{image:{name:"görüntü"}}},Qi={description:"İstem ve maskeye göre görüntüyü değiştirin.",display_name:"Recraft Görüntü İç Boyama",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü"},mask:{name:"maske"},n:{name:"n",tooltip:"Oluşturulacak görüntü sayısı."},negative_prompt:{name:"negatif_istem",tooltip:"Bir görüntüde istenmeyen öğelerin isteğe bağlı metin açıklaması."},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi."},recraft_style:{name:"recraft_stili"},seed:{name:"tohum",tooltip:"Düğümün yeniden çalışıp çalışmayacağını belirlemek için tohum; gerçek sonuçlar tohumdan bağımsız olarak belirleyici değildir."}}},Ji={description:"İstem ve güce göre görüntüyü değiştirin.",display_name:"Recraft Görüntüden Görüntüye",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü"},n:{name:"n",tooltip:"Oluşturulacak görüntü sayısı."},negative_prompt:{name:"negatif_istem",tooltip:"Bir görüntüde istenmeyen öğelerin isteğe bağlı metin açıklaması."},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi."},recraft_controls:{name:"recraft_kontrolleri",tooltip:"Recraft Kontrolleri düğümü aracılığıyla üretim üzerinde isteğe bağlı ek kontroller."},recraft_style:{name:"recraft_stili"},seed:{name:"tohum",tooltip:"Düğümün yeniden çalışıp çalışmayacağını belirlemek için tohum; gerçek sonuçlar tohumdan bağımsız olarak belirleyici değildir."},strength:{name:"güç",tooltip:"Orijinal görüntü ile farkı tanımlar, [0, 1] aralığında olmalıdır, burada 0 neredeyse aynı anlamına gelir ve 1 sefil bir benzerlik anlamına gelir."}}},$i={description:"Görüntüden arka planı kaldırın ve işlenmiş görüntüyü ve maskeyi döndürün.",display_name:"Recraft Arka Planı Kaldır",inputs:{image:{name:"görüntü"}}},el={description:"Sağlanan isteme göre görüntüdeki arka planı değiştirin.",display_name:"Recraft Arka Planı Değiştir",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü"},n:{name:"n",tooltip:"Oluşturulacak görüntü sayısı."},negative_prompt:{name:"negatif_istem",tooltip:"Bir görüntüde istenmeyen öğelerin isteğe bağlı metin açıklaması."},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi."},recraft_style:{name:"recraft_stili"},seed:{name:"tohum",tooltip:"Düğümün yeniden çalışıp çalışmayacağını belirlemek için tohum; gerçek sonuçlar tohumdan bağımsız olarak belirleyici değildir."}}},al={description:"Gerçekçi_görüntü stilini ve isteğe bağlı alt stili seçin.",display_name:"Recraft Stili - Dijital İllüstrasyon",inputs:{substyle:{name:"alt_stil"}},outputs:{0:{name:"recraft_stili"}}},nl={description:"Recraft'ın Sonsuz Stil Kütüphanesinden önceden var olan UUID'ye göre stil seçin.",display_name:"Recraft Stili - Sonsuz Stil Kütüphanesi",inputs:{style_id:{name:"stil_kimliği",tooltip:"Sonsuz Stil Kütüphanesinden stilin UUID'si."}},outputs:{0:{name:"recraft_stili"}}},il={description:"Gerçekçi_görüntü stilini ve isteğe bağlı alt stili seçin.",display_name:"Recraft Stili - Logo Raster",inputs:{substyle:{name:"alt_stil"}},outputs:{0:{name:"recraft_stili"}}},ll={description:"Gerçekçi_görüntü stilini ve isteğe bağlı alt stili seçin.",display_name:"Recraft Stili - Gerçekçi Görüntü",inputs:{substyle:{name:"alt_stil"}},outputs:{0:{name:"recraft_stili"}}},tl={description:"İstem ve çözünürlüğe göre görüntüleri eşzamanlı olarak oluşturur.",display_name:"Recraft Metinden Görüntüye",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},n:{name:"n",tooltip:"Oluşturulacak görüntü sayısı."},negative_prompt:{name:"negatif_istem",tooltip:"Bir görüntüde istenmeyen öğelerin isteğe bağlı metin açıklaması."},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi."},recraft_controls:{name:"recraft_kontrolleri",tooltip:"Recraft Kontrolleri düğümü aracılığıyla üretim üzerinde isteğe bağlı ek kontroller."},recraft_style:{name:"recraft_stili"},seed:{name:"tohum",tooltip:"Düğümün yeniden çalışıp çalışmayacağını belirlemek için tohum; gerçek sonuçlar tohumdan bağımsız olarak belirleyici değildir."},size:{name:"boyut",tooltip:"Oluşturulan görüntünün boyutu."}}},ol={description:"İstem ve çözünürlüğe göre SVG'yi eşzamanlı olarak oluşturur.",display_name:"Recraft Metinden Vektöre",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},n:{name:"n",tooltip:"Oluşturulacak görüntü sayısı."},negative_prompt:{name:"negatif_istem",tooltip:"Bir görüntüde istenmeyen öğelerin isteğe bağlı metin açıklaması."},prompt:{name:"istem",tooltip:"Görüntü oluşturma istemi."},recraft_controls:{name:"recraft_kontrolleri",tooltip:"Recraft Kontrolleri düğümü aracılığıyla üretim üzerinde isteğe bağlı ek kontroller."},seed:{name:"tohum",tooltip:"Düğümün yeniden çalışıp çalışmayacağını belirlemek için tohum; gerçek sonuçlar tohumdan bağımsız olarak belirleyici değildir."},size:{name:"boyut",tooltip:"Oluşturulan görüntünün boyutu."},substyle:{name:"alt_stil"}}},ml={description:"Bir giriş görüntüsünden eşzamanlı olarak SVG oluşturur.",display_name:"Recraft Görüntüyü Vektörleştir",inputs:{image:{name:"görüntü"}}},rl={display_name:"YenidenNormalleştirCFG",inputs:{cfg_trunc:{name:"cfg_kesme"},model:{name:"model"},renorm_cfg:{name:"yenidenorm_cfg"}}},sl={display_name:"GörüntüGrubunuTekrarla",inputs:{amount:{name:"miktar"},image:{name:"görüntü"}}},_l={display_name:"Gizli Grubu Tekrarla",inputs:{amount:{name:"miktar"},samples:{name:"örnekler"}}},kl={display_name:"CFG'yiYenidenÖlçekle",inputs:{model:{name:"model"},multiplier:{name:"çarpan"}}},dl={display_name:"SDTurboZamanlayıcı",inputs:{denoise:{name:"gürültü_azaltma"},model:{name:"model"},steps:{name:"adımlar"}}},pl={display_name:"SD_4X_Büyütme_Koşullandırma",inputs:{images:{name:"görüntüler"},negative:{name:"negatif"},noise_augmentation:{name:"gürültü_artırımı"},positive:{name:"pozitif"},scale_ratio:{name:"ölçek_oranı"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},ul={display_name:"SV3D_Koşullandırma",inputs:{clip_vision:{name:"clip_görü"},elevation:{name:"yükseklik"},height:{name:"yükseklik"},init_image:{name:"başlangıç_görüntüsü"},vae:{name:"vae"},video_frames:{name:"video_kareleri"},width:{name:"genişlik"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},cl={display_name:"SVD_görüntüden_videoya_Koşullandırma",inputs:{augmentation_level:{name:"artırma_seviyesi"},clip_vision:{name:"clip_görü"},fps:{name:"fps"},height:{name:"yükseklik"},init_image:{name:"başlangıç_görüntüsü"},motion_bucket_id:{name:"hareket_kovası_kimliği"},vae:{name:"vae"},video_frames:{name:"video_kareleri"},width:{name:"genişlik"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},gl={display_name:"ÖzelÖrnekleyici",inputs:{add_noise:{name:"gürültü_ekle"},cfg:{name:"cfg"},control_after_generate:{name:"oluşturduktan sonra kontrol et"},latent_image:{name:"gizli_görüntü"},model:{name:"model"},negative:{name:"negatif"},noise_seed:{name:"gürültü_tohumu"},positive:{name:"pozitif"},sampler:{name:"örnekleyici"},sigmas:{name:"sigmalar"}},outputs:{0:{name:"çıktı"},1:{name:"gürültüsü_alınmış_çıktı"}}},bl={display_name:"GelişmişÖzelÖrnekleyici",inputs:{guider:{name:"rehber"},latent_image:{name:"gizli_görüntü"},noise:{name:"gürültü"},sampler:{name:"örnekleyici"},sigmas:{name:"sigmalar"}},outputs:{0:{name:"çıktı"},1:{name:"gürültüsü_alınmış_çıktı"}}},yl={display_name:"UyarlanabilirDPMÖrnekleyici",inputs:{accept_safety:{name:"kabul_güvenliği"},atol:{name:"atol"},dcoeff:{name:"dkatsayı"},eta:{name:"eta"},h_init:{name:"h_başlangıç"},icoeff:{name:"ikatsayı"},order:{name:"sıra"},pcoeff:{name:"pkatsayı"},rtol:{name:"rtol"},s_noise:{name:"s_gürültü"}}},fl={display_name:"ÖrnekleyiciDPMPP_2M_SDE",inputs:{eta:{name:"eta"},noise_device:{name:"gürültü_cihazı"},s_noise:{name:"s_gürültü"},solver_type:{name:"çözücü_türü"}}},hl={display_name:"ÖrnekleyiciDPMPP_2S_Atasal",inputs:{eta:{name:"eta"},s_noise:{name:"s_gürültü"}}},zl={display_name:"ÖrnekleyiciDPMPP_3M_SDE",inputs:{eta:{name:"eta"},noise_device:{name:"gürültü_cihazı"},s_noise:{name:"s_gürültü"}}},vl={display_name:"ÖrnekleyiciDPMPP_SDE",inputs:{eta:{name:"eta"},noise_device:{name:"gürültü_cihazı"},r:{name:"r"},s_noise:{name:"s_gürültü"}}},Sl={display_name:"Euler Atasal Örnekleyici",inputs:{eta:{name:"eta"},s_noise:{name:"s_gürültü"}}},Ll={display_name:"Euler Atasal Örnekleyici CFG++",inputs:{eta:{name:"eta"},s_noise:{name:"s_gürültü"}}},Cl={display_name:"Euler Örnekleyici CFG++",inputs:{version:{name:"sürüm"}}},Ml={display_name:"LCM Büyütme Örnekleyici",inputs:{scale_ratio:{name:"ölçek_oranı"},scale_steps:{name:"ölçek_adımları"},upscale_method:{name:"büyütme_yöntemi"}}},Gl={display_name:"LMS Örnekleyici",inputs:{order:{name:"sıra"}}},Vl={display_name:"Animasyonlu PNG Kaydet",inputs:{compress_level:{name:"sıkıştırma_seviyesi"},filename_prefix:{name:"dosyaadı_öneki"},fps:{name:"fps"},images:{name:"görüntüler"}}},Il={display_name:"Animasyonlu WEBP Kaydet",inputs:{filename_prefix:{name:"dosyaadı_öneki"},fps:{name:"fps"},images:{name:"görüntüler"},lossless:{name:"kayıpsız"},method:{name:"yöntem"},quality:{name:"kalite"}}},Al={display_name:"Sesi Kaydet",inputs:{audio:{name:"ses"},audioUI:{name:"sesArayüzü"},filename_prefix:{name:"dosyaadı_öneki"}}},Pl={display_name:"GLB Kaydet",inputs:{filename_prefix:{name:"dosyaadı_öneki"},image:{name:"görüntü"},mesh:{name:"ağ"}}},Dl={description:"Giriş görüntülerini ComfyUI çıktı dizininize kaydeder.",display_name:"Görüntüyü Kaydet",inputs:{filename_prefix:{name:"dosyaadı_öneki",tooltip:"Kaydedilecek dosyanın öneki. Bu, düğümlerden değerleri dahil etmek için %date:yyyy-MM-dd% veya %Empty Latent Image.width% gibi biçimlendirme bilgileri içerebilir."},images:{name:"görüntüler",tooltip:"Kaydedilecek görüntüler."}}},Kl={display_name:"GörüntüyüWebsocketKaydet",inputs:{images:{name:"görüntüler"}}},xl={display_name:"GizliDeğişkeniKaydet",inputs:{filename_prefix:{name:"dosyaadı_öneki"},samples:{name:"örnekler"}}},Bl={description:"Giriş görüntülerini ComfyUI çıktı dizininize kaydeder.",display_name:"Videoyu Kaydet",inputs:{codec:{name:"codec",tooltip:"Video için kullanılacak codec."},filename_prefix:{name:"dosyaadı_öneki",tooltip:"Kaydedilecek dosyanın öneki. Bu, düğümlerden değerleri dahil etmek için %date:yyyy-MM-dd% veya %Empty Latent Image.width% gibi biçimlendirme bilgileri içerebilir."},format:{name:"format",tooltip:"Videonun kaydedileceği format."},video:{name:"video",tooltip:"Kaydedilecek video."}}},Tl={display_name:"WEBM Kaydet",inputs:{codec:{name:"codec"},crf:{name:"crf",tooltip:"Daha yüksek crf, daha küçük dosya boyutuyla daha düşük kalite anlamına gelir, daha düşük crf ise daha yüksek kalite daha yüksek dosya boyutu anlamına gelir."},filename_prefix:{name:"dosyaadı_öneki"},fps:{name:"fps"},images:{name:"görüntüler"}}},El={display_name:"Öz-Dikkat Rehberliği",inputs:{blur_sigma:{name:"bulanıklık_sigma"},model:{name:"model"},scale:{name:"ölçek"}}},Nl={display_name:"CLIP Kancalarını Ayarla",inputs:{apply_to_conds:{name:"koşullara_uygula"},clip:{name:"clip"},hooks:{name:"kancalar"},schedule_clip:{name:"zamanlama_klibi"}}},Rl={display_name:"İlkSigmayıAyarla",inputs:{sigma:{name:"sigma"},sigmas:{name:"sigmalar"}}},Fl={display_name:"Kanca Anahtar Karelerini Ayarla",inputs:{hook_kf:{name:"kanca_kf"},hooks:{name:"kancalar"}}},Ul={display_name:"Gizli Gürültü Maskesi Ayarla",inputs:{mask:{name:"maske"},samples:{name:"örnekler"}}},wl={display_name:"BileşimControlNetTürüAyarla",inputs:{control_net:{name:"kontrol_ağı"},type:{name:"tür"}}},Ol={description:"Her DiT modelinde kullanılabilecek SkipLayerGuidance düğümünün genel bir sürümü.",display_name:"KatmanAtlamaRehberliğiDiT",inputs:{double_layers:{name:"çift_katmanlar"},end_percent:{name:"bitiş_yüzdesi"},model:{name:"model"},rescaling_scale:{name:"yeniden_ölçeklendirme_ölçeği"},scale:{name:"ölçek"},single_layers:{name:"tek_katmanlar"},start_percent:{name:"başlangıç_yüzdesi"}}},jl={description:"Her DiT modelinde kullanılabilecek SkipLayerGuidance düğümünün genel bir sürümü.",display_name:"KatmanAtlamaRehberliğiSD3",inputs:{end_percent:{name:"bitiş_yüzdesi"},layers:{name:"katmanlar"},model:{name:"model"},scale:{name:"ölçek"},start_percent:{name:"başlangıç_yüzdesi"}}},Hl={display_name:"KatıMaske",inputs:{height:{name:"yükseklik"},value:{name:"değer"},width:{name:"genişlik"}}},Yl={display_name:"Görüntüyü Alfa ile Böl",inputs:{image:{name:"görüntü"}}},Wl={display_name:"SigmalarıBöl",inputs:{sigmas:{name:"sigmalar"},step:{name:"adım"}},outputs:{0:{name:"yüksek_sigmalar"},1:{name:"düşük_sigmalar"}}},Xl={display_name:"SigmalarıGürültüAzaltmaBöl",inputs:{denoise:{name:"gürültü_azaltma"},sigmas:{name:"sigmalar"}},outputs:{0:{name:"yüksek_sigmalar"},1:{name:"düşük_sigmalar"}}},Zl={description:"İstem ve çözünürlüğe göre görüntüleri eşzamanlı olarak oluşturur.",display_name:"Stability AI Stable Diffusion 3.5 Görüntü",inputs:{aspect_ratio:{name:"en_boy_oranı",tooltip:"Oluşturulan görüntünün en boy oranı."},cfg_scale:{name:"cfg_ölçeği",tooltip:"Difüzyon sürecinin istem metnine ne kadar sıkı bir şekilde bağlı kaldığı (daha yüksek değerler görüntünüzü isteminize daha yakın tutar)"},control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü"},image_denoise:{name:"görüntü_gürültü_azaltma",tooltip:"Giriş görüntüsünün gürültüsünün azaltılması; 0.0 girdiyle aynı bir görüntü verir, 1.0 ise hiç görüntü sağlanmamış gibidir."},model:{name:"model"},negative_prompt:{name:"negatif_istem",tooltip:"Çıktı görüntüsünde ne görmek istemediğinizin anahtar kelimeleri. Bu gelişmiş bir özelliktir."},prompt:{name:"istem",tooltip:"Çıktı görüntüsünde ne görmek istediğiniz. Öğeleri, renkleri ve konuları açıkça tanımlayan güçlü, açıklayıcı bir istem daha iyi sonuçlara yol açacaktır."},seed:{name:"tohum",tooltip:"Gürültüyü oluşturmak için kullanılan rastgele tohum."},style_preset:{name:"stil_önayarı",tooltip:"Oluşturulan görüntünün isteğe bağlı istenen stili."}}},ql={description:"İstem ve çözünürlüğe göre görüntüleri eşzamanlı olarak oluşturur.",display_name:"Stability AI Stable Image Ultra",inputs:{aspect_ratio:{name:"en_boy_oranı",tooltip:"Oluşturulan görüntünün en boy oranı."},control_after_generate:{name:"oluşturduktan sonra kontrol et"},image:{name:"görüntü"},image_denoise:{name:"görüntü_gürültü_azaltma",tooltip:"Giriş görüntüsünün gürültüsünün azaltılması; 0.0 girdiyle aynı bir görüntü verir, 1.0 ise hiç görüntü sağlanmamış gibidir."},negative_prompt:{name:"negatif_istem",tooltip:"Çıktı görüntüsünde ne görmek istemediğinizi anlatan bir metin. Bu gelişmiş bir özelliktir."},prompt:{name:"istem",tooltip:"Çıktı görüntüsünde ne görmek istediğiniz. Öğeleri, renkleri ve konuları açıkça tanımlayan güçlü, açıklayıcı bir istem daha iyi sonuçlara yol açacaktır. Belirli bir kelimenin ağırlığını kontrol etmek için (kelime:ağırlık) formatını kullanın, burada 'kelime' ağırlığını kontrol etmek istediğiniz kelime ve 'ağırlık' 0 ile 1 arasında bir değerdir. Örneğin: 'Gökyüzü berrak (mavi:0.3) ve (yeşil:0.8) idi' mavi ve yeşil bir gökyüzü, ancak maviden daha çok yeşil olduğunu ifade eder."},seed:{name:"tohum",tooltip:"Gürültüyü oluşturmak için kullanılan rastgele tohum."},style_preset:{name:"stil_önayarı",tooltip:"Oluşturulan görüntünün isteğe bağlı istenen stili."}}},Ql={description:"Görüntüyü minimum değişiklikle 4K çözünürlüğe büyütün.",display_name:"Stability AI Büyütme Muhafazakar",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},creativity:{name:"yaratıcılık",tooltip:"Başlangıç görüntüsü tarafından yoğun bir şekilde koşullandırılmayan ek ayrıntılar oluşturma olasılığını kontrol eder."},image:{name:"görüntü"},negative_prompt:{name:"negatif_istem",tooltip:"Çıktı görüntüsünde ne görmek istemediğinizin anahtar kelimeleri. Bu gelişmiş bir özelliktir."},prompt:{name:"istem",tooltip:"Çıktı görüntüsünde ne görmek istediğiniz. Öğeleri, renkleri ve konuları açıkça tanımlayan güçlü, açıklayıcı bir istem daha iyi sonuçlara yol açacaktır."},seed:{name:"tohum",tooltip:"Gürültüyü oluşturmak için kullanılan rastgele tohum."}}},Jl={description:"Görüntüyü minimum değişiklikle 4K çözünürlüğe büyütün.",display_name:"Stability AI Büyütme Yaratıcı",inputs:{control_after_generate:{name:"oluşturduktan sonra kontrol et"},creativity:{name:"yaratıcılık",tooltip:"Başlangıç görüntüsü tarafından yoğun bir şekilde koşullandırılmayan ek ayrıntılar oluşturma olasılığını kontrol eder."},image:{name:"görüntü"},negative_prompt:{name:"negatif_istem",tooltip:"Çıktı görüntüsünde ne görmek istemediğinizin anahtar kelimeleri. Bu gelişmiş bir özelliktir."},prompt:{name:"istem",tooltip:"Çıktı görüntüsünde ne görmek istediğiniz. Öğeleri, renkleri ve konuları açıkça tanımlayan güçlü, açıklayıcı bir istem daha iyi sonuçlara yol açacaktır."},seed:{name:"tohum",tooltip:"Gürültüyü oluşturmak için kullanılan rastgele tohum."},style_preset:{name:"stil_önayarı",tooltip:"Oluşturulan görüntünün isteğe bağlı istenen stili."}}},$l={description:"Stability API çağrısı aracılığıyla bir görüntüyü orijinal boyutunun 4 katına kadar hızlı bir şekilde büyütür; düşük kaliteli/sıkıştırılmış görüntüleri büyütmek için tasarlanmıştır.",display_name:"Stability AI Hızlı Büyütme",inputs:{image:{name:"görüntü"}}},et={display_name:"StabilKaskad_BoşGizliGörüntü",inputs:{batch_size:{name:"toplu_boyut"},compression:{name:"sıkıştırma"},height:{name:"yükseklik"},width:{name:"genişlik"}},outputs:{0:{name:"aşama_c"},1:{name:"aşama_b"}}},at={display_name:"StabilKaskad_AşamaB_Koşullandırma",inputs:{conditioning:{name:"koşullandırma"},stage_c:{name:"aşama_c"}}},nt={display_name:"StabilKaskad_AşamaC_VAEKodlama",inputs:{compression:{name:"sıkıştırma"},image:{name:"görüntü"},vae:{name:"vae"}},outputs:{0:{name:"aşama_c"},1:{name:"aşama_b"}}},it={display_name:"StabilKaskad_SüperÇözünürlükKontrolAğı",inputs:{image:{name:"görüntü"},vae:{name:"vae"}},outputs:{0:{name:"kontrol_ağı_girişi"},1:{name:"aşama_c"},2:{name:"aşama_b"}}},lt={display_name:"StabilSıfır123_Koşullandırma",inputs:{azimuth:{name:"azimut"},batch_size:{name:"toplu_boyut"},clip_vision:{name:"clip_görü"},elevation:{name:"yükseklik"},height:{name:"yükseklik"},init_image:{name:"başlangıç_görüntüsü"},vae:{name:"vae"},width:{name:"genişlik"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},tt={display_name:"StabilSıfır123_Koşullandırma_Toplu",inputs:{azimuth:{name:"azimut"},azimuth_batch_increment:{name:"azimut_toplu_artışı"},batch_size:{name:"toplu_boyut"},clip_vision:{name:"clip_görü"},elevation:{name:"yükseklik"},elevation_batch_increment:{name:"yükseklik_toplu_artışı"},height:{name:"yükseklik"},init_image:{name:"başlangıç_görüntüsü"},vae:{name:"vae"},width:{name:"genişlik"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},ot={display_name:"Stil Modeli Uygula",inputs:{clip_vision_output:{name:"clip_görü_çıktısı"},conditioning:{name:"koşullandırma"},strength:{name:"güç"},strength_type:{name:"güç_türü"},style_model:{name:"stil_modeli"}}},mt={display_name:"Stil Modeli Yükle",inputs:{style_model_name:{name:"stil_modeli_adı"}}},rt={display_name:"T5JetonlaştırıcıSeçenekleri",inputs:{clip:{name:"clip"},min_length:{name:"min_uzunluk"},min_padding:{name:"min_dolgu"}}},st={display_name:"MetinKodlamaHunyuanVideo_GörüntüdenVideoya",inputs:{clip:{name:"clip"},clip_vision_output:{name:"clip_görü_çıktısı"},image_interleave:{name:"görüntü_serpiştirme",tooltip:"Görüntünün metin istemine karşı ne kadar etkili olduğu. Daha yüksek sayı, metin isteminden daha fazla etki anlamına gelir."},prompt:{name:"istem"}}},_t={display_name:"EşikMaskesi",inputs:{mask:{name:"maske"},value:{name:"değer"}}},kt={display_name:"Tome Model Yaması",inputs:{model:{name:"model"},ratio:{name:"oran"}}},dt={display_name:"Torch Model Derleme",inputs:{backend:{name:"arka_uç"},model:{name:"model"}}},pt={display_name:"VideoGizliDeğişkeniniKırp",inputs:{samples:{name:"örnekler"},trim_amount:{name:"kırpma_miktarı"}}},ut={description:`[Tarifler]

sd3: clip-l, clip-g, t5`,display_name:"ÜçlüCLIPYükleyici",inputs:{clip_name1:{name:"clip_adı1"},clip_name2:{name:"clip_adı2"},clip_name3:{name:"clip_adı3"}}},ct={display_name:"Difüzyon Modeli Yükle",inputs:{unet_name:{name:"unet_adı"},weight_dtype:{name:"ağırlık_veri_türü"}}},gt={display_name:"UNetÇaprazDikkatÇarpımı",inputs:{k:{name:"k"},model:{name:"model"},out:{name:"çıktı"},q:{name:"q"},v:{name:"v"}}},bt={display_name:"UNetÖzDikkatÇarpımı",inputs:{k:{name:"k"},model:{name:"model"},out:{name:"çıktı"},q:{name:"q"},v:{name:"v"}}},yt={display_name:"UNetZamansalDikkatÇarpımı",inputs:{cross_structural:{name:"çapraz_yapısal"},cross_temporal:{name:"çapraz_zamansal"},model:{name:"model"},self_structural:{name:"öz_yapısal"},self_temporal:{name:"öz_zamansal"}}},ft={display_name:"Büyütme Modeli Yükle",inputs:{model_name:{name:"model_adı"}}},ht={description:"Gizli görüntüleri tekrar piksel uzayı görüntülerine çözer.",display_name:"VAE Kod Çözme",inputs:{samples:{name:"örnekler",tooltip:"Kodunun çözüleceği gizli değişken."},vae:{name:"vae",tooltip:"Gizli değişkenin kodunu çözmek için kullanılan VAE modeli."}},outputs:{0:{tooltip:"Kodu çözülmüş görüntü."}}},zt={display_name:"VAESesKodunuÇöz",inputs:{samples:{name:"örnekler"},vae:{name:"vae"}}},vt={display_name:"VAEKodÇözmeHunyuan3D",inputs:{num_chunks:{name:"parça_sayısı"},octree_resolution:{name:"sekizli_ağaç_çözünürlüğü"},samples:{name:"örnekler"},vae:{name:"vae"}}},St={display_name:"VAE Kod Çözme (Döşemeli)",inputs:{overlap:{name:"örtüşme"},samples:{name:"örnekler"},temporal_overlap:{name:"zamansal_örtüşme",tooltip:"Yalnızca video VAE'leri için kullanılır: Örtüşecek kare sayısı."},temporal_size:{name:"zamansal_boyut",tooltip:"Yalnızca video VAE'leri için kullanılır: Bir seferde kodu çözülecek kare sayısı."},tile_size:{name:"döşeme_boyutu"},vae:{name:"vae"}}},Lt={display_name:"VAE Kodlama",inputs:{pixels:{name:"pikseller"},vae:{name:"vae"}}},Ct={display_name:"VAESesKodla",inputs:{audio:{name:"ses"},vae:{name:"vae"}}},Mt={display_name:"VAE Kodlama (İç Boyama için)",inputs:{grow_mask_by:{name:"maskeyi_büyüt"},mask:{name:"maske"},pixels:{name:"pikseller"},vae:{name:"vae"}}},Gt={display_name:"VAE Kodlama (Döşemeli)",inputs:{overlap:{name:"örtüşme"},pixels:{name:"pikseller"},temporal_overlap:{name:"zamansal_örtüşme",tooltip:"Yalnızca video VAE'leri için kullanılır: Örtüşecek kare sayısı."},temporal_size:{name:"zamansal_boyut",tooltip:"Yalnızca video VAE'leri için kullanılır: Bir seferde kodlanacak kare sayısı."},tile_size:{name:"döşeme_boyutu"},vae:{name:"vae"}}},Vt={display_name:"VAE Yükle",inputs:{vae_name:{name:"vae_adı"}}},It={display_name:"VAEKaydet",inputs:{filename_prefix:{name:"dosyaadı_öneki"},vae:{name:"vae"}}},At={display_name:"VPZamanlayıcı",inputs:{beta_d:{name:"beta_d"},beta_min:{name:"beta_min"},eps_s:{name:"eps_s"},steps:{name:"adımlar"}}},Pt={description:"Google'ın Veo API'sini kullanarak metin istemlerinden videolar oluşturur",display_name:"Google Veo2 Video Oluşturma",inputs:{aspect_ratio:{name:"en_boy_oranı",tooltip:"Çıktı videosunun en boy oranı"},control_after_generate:{name:"oluşturduktan sonra kontrol et"},duration_seconds:{name:"süre_saniye",tooltip:"Çıktı videosunun saniye cinsinden süresi"},enhance_prompt:{name:"istemi_geliştir",tooltip:"İstemi yapay zeka yardımıyla geliştirip geliştirmeme"},image:{name:"görüntü",tooltip:"Video oluşturmayı yönlendirmek için isteğe bağlı referans görüntü"},negative_prompt:{name:"negatif_istem",tooltip:"Videoda kaçınılması gerekenleri yönlendirmek için negatif metin istemi"},person_generation:{name:"kişi_oluşturma",tooltip:"Videoda insan oluşturmaya izin verip vermeme"},prompt:{name:"istem",tooltip:"Videonun metin açıklaması"},seed:{name:"tohum",tooltip:"Video oluşturma için tohum (rastgele için 0)"}}},Dt={display_name:"VideoDoğrusalCFGRehberliği",inputs:{min_cfg:{name:"min_cfg"},model:{name:"model"}}},Kt={display_name:"VideoÜçgenCFGRehberliği",inputs:{min_cfg:{name:"min_cfg"},model:{name:"model"}}},xt={display_name:"VokseldenAğa",inputs:{algorithm:{name:"algoritma"},threshold:{name:"eşik"},voxel:{name:"voksel"}}},Bt={display_name:"TemelVokseldenAğa",inputs:{threshold:{name:"eşik"},voxel:{name:"voksel"}}},Tt={display_name:"WanİlkSonKaredenVideoya",inputs:{batch_size:{name:"toplu_boyut"},clip_vision_end_image:{name:"clip_görü_bitiş_görüntüsü"},clip_vision_start_image:{name:"clip_görü_başlangıç_görüntüsü"},end_image:{name:"bitiş_görüntüsü"},height:{name:"yükseklik"},length:{name:"uzunluk"},negative:{name:"negatif"},positive:{name:"pozitif"},start_image:{name:"başlangıç_görüntüsü"},vae:{name:"vae"},width:{name:"genişlik"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},Et={display_name:"WanEğlenceKontroldenVideoya",inputs:{batch_size:{name:"toplu_boyut"},clip_vision_output:{name:"clip_görü_çıktısı"},control_video:{name:"kontrol_videosu"},height:{name:"yükseklik"},length:{name:"uzunluk"},negative:{name:"negatif"},positive:{name:"pozitif"},start_image:{name:"başlangıç_görüntüsü"},vae:{name:"vae"},width:{name:"genişlik"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},Nt={display_name:"WanEğlenceİçBoyamadanVideoya",inputs:{batch_size:{name:"toplu_boyut"},clip_vision_output:{name:"clip_görü_çıktısı"},end_image:{name:"bitiş_görüntüsü"},height:{name:"yükseklik"},length:{name:"uzunluk"},negative:{name:"negatif"},positive:{name:"pozitif"},start_image:{name:"başlangıç_görüntüsü"},vae:{name:"vae"},width:{name:"genişlik"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},Rt={display_name:"WanGörüntüdenVideoya",inputs:{batch_size:{name:"toplu_boyut"},clip_vision_output:{name:"clip_görü_çıktısı"},height:{name:"yükseklik"},length:{name:"uzunluk"},negative:{name:"negatif"},positive:{name:"pozitif"},start_image:{name:"başlangıç_görüntüsü"},vae:{name:"vae"},width:{name:"genişlik"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"}}},Ft={display_name:"WanVace'denVideoya",inputs:{batch_size:{name:"toplu_boyut"},control_masks:{name:"kontrol_maskeleri"},control_video:{name:"kontrol_videosu"},height:{name:"yükseklik"},length:{name:"uzunluk"},negative:{name:"negatif"},positive:{name:"pozitif"},reference_image:{name:"referans_görüntüsü"},strength:{name:"güç"},vae:{name:"vae"},width:{name:"genişlik"}},outputs:{0:{name:"pozitif"},1:{name:"negatif"},2:{name:"gizli"},3:{name:"gizliyi_kırp"}}},Ut={display_name:"Webcam Yakalama",inputs:{capture_on_queue:{name:"kuyrukta_yakala"},height:{name:"yükseklik"},image:{name:"görüntü"},"waiting for camera___":{},width:{name:"genişlik"}}},wt={display_name:"unCLIPKontrolNoktasıYükleyici",inputs:{ckpt_name:{name:"ckpt_adı"}}},Ot={display_name:"unCLIPKoşullandırma",inputs:{clip_vision_output:{name:"clip_görü_çıktısı"},conditioning:{name:"koşullandırma"},noise_augmentation:{name:"gürültü_artırımı"},strength:{name:"güç"}}},jt={AddNoise:e,AlignYourStepsScheduler:a,BasicGuider:n,BasicScheduler:i,BetaSamplingScheduler:l,CFGGuider:t,CFGZeroStar:o,CLIPAttentionMultiply:m,CLIPLoader:r,CLIPMergeAdd:s,CLIPMergeSimple:_,CLIPMergeSubtract:k,CLIPSave:d,CLIPSetLastLayer:p,CLIPTextEncode:u,CLIPTextEncodeControlnet:c,CLIPTextEncodeFlux:g,CLIPTextEncodeHiDream:b,CLIPTextEncodeHunyuanDiT:y,CLIPTextEncodeLumina2:f,CLIPTextEncodePixArtAlpha:h,CLIPTextEncodeSD3:z,CLIPTextEncodeSDXL:v,CLIPTextEncodeSDXLRefiner:S,CLIPVisionEncode:L,CLIPVisionLoader:C,Canny:M,CheckpointLoader:G,CheckpointLoaderSimple:V,CheckpointSave:I,CombineHooks2:A,CombineHooks4:P,CombineHooks8:D,ConditioningAverage:K,ConditioningCombine:x,ConditioningConcat:B,ConditioningSetArea:T,ConditioningSetAreaPercentage:E,ConditioningSetAreaPercentageVideo:N,ConditioningSetAreaStrength:R,ConditioningSetDefaultCombine:F,ConditioningSetMask:U,ConditioningSetProperties:w,ConditioningSetPropertiesAndCombine:O,ConditioningSetTimestepRange:j,ConditioningStableAudio:H,ConditioningTimestepsRange:Y,ConditioningZeroOut:W,ControlNetApply:X,ControlNetApplyAdvanced:Z,ControlNetApplySD3:q,ControlNetInpaintingAliMamaApply:Q,ControlNetLoader:J,CosmosImageToVideoLatent:$,CreateHookKeyframe:ee,CreateHookKeyframesFromFloats:ae,CreateHookKeyframesInterpolated:ne,CreateHookLora:ie,CreateHookLoraModelOnly:le,CreateHookModelAsLora:te,CreateHookModelAsLoraModelOnly:oe,CreateVideo:me,CropMask:re,DiffControlNetLoader:se,DifferentialDiffusion:_e,DiffusersLoader:ke,DisableNoise:de,DualCFGGuider:pe,DualCLIPLoader:ue,EmptyCosmosLatentVideo:ce,EmptyHunyuanLatentVideo:ge,EmptyImage:be,EmptyLTXVLatentVideo:ye,EmptyLatentAudio:fe,EmptyLatentHunyuan3Dv2:he,EmptyLatentImage:ze,EmptyMochiLatentVideo:ve,EmptySD3LatentImage:Se,ExponentialScheduler:Le,ExtendIntermediateSigmas:Ce,FeatherMask:Me,FlipSigmas:Ge,FluxDisableGuidance:Ve,FluxGuidance:Ie,FluxProExpandNode:Ae,FluxProFillNode:Pe,FluxProUltraImageNode:De,FreSca:Ke,FreeU:xe,FreeU_V2:Be,GITSScheduler:Te,GLIGENLoader:Ee,GLIGENTextBoxApply:Ne,GetVideoComponents:Re,GrowMask:Fe,Hunyuan3Dv2Conditioning:Ue,Hunyuan3Dv2ConditioningMultiView:we,HunyuanImageToVideo:Oe,HyperTile:je,HypernetworkLoader:He,IdeogramV1:Ye,IdeogramV2:We,IdeogramV3:Xe,ImageBatch:Ze,ImageBlend:qe,ImageBlur:Qe,ImageColorToMask:Je,ImageCompositeMasked:$e,ImageCrop:ea,ImageFromBatch:aa,ImageInvert:na,ImageOnlyCheckpointLoader:ia,ImageOnlyCheckpointSave:la,ImagePadForOutpaint:ta,ImageQuantize:oa,ImageRGBToYUV:ma,ImageScale:ra,ImageScaleBy:sa,ImageScaleToTotalPixels:_a,ImageSharpen:ka,ImageToMask:da,ImageUpscaleWithModel:pa,ImageYUVToRGB:ua,InpaintModelConditioning:ca,InstructPixToPixConditioning:ga,InvertMask:ba,JoinImageWithAlpha:ya,KSampler:fa,KSamplerAdvanced:ha,KSamplerSelect:za,KarrasScheduler:va,KlingCameraControlI2VNode:Sa,KlingCameraControlT2VNode:La,KlingCameraControls:Ca,KlingDualCharacterVideoEffectNode:Ma,KlingImage2VideoNode:Ga,KlingImageGenerationNode:Va,KlingLipSyncAudioToVideoNode:Ia,KlingLipSyncTextToVideoNode:Aa,KlingSingleImageVideoEffectNode:Pa,KlingStartEndFrameNode:Da,KlingTextToVideoNode:Ka,KlingVideoExtendNode:xa,KlingVirtualTryOnNode:Ba,LTXVAddGuide:Ta,LTXVConditioning:Ea,LTXVCropGuides:Na,LTXVImgToVideo:Ra,LTXVPreprocess:Fa,LTXVScheduler:Ua,LaplaceScheduler:wa,LatentAdd:Oa,LatentApplyOperation:ja,LatentApplyOperationCFG:Ha,LatentBatch:Ya,LatentBatchSeedBehavior:Wa,LatentBlend:Xa,LatentComposite:Za,LatentCompositeMasked:qa,LatentCrop:Qa,LatentFlip:Ja,LatentFromBatch:$a,LatentInterpolate:en,LatentMultiply:an,LatentOperationSharpen:nn,LatentOperationTonemapReinhard:ln,LatentRotate:tn,LatentSubtract:on,LatentUpscale:mn,LatentUpscaleBy:rn,Load3D:sn,Load3DAnimation:_n,LoadAudio:kn,LoadImage:dn,LoadImageMask:pn,LoadImageOutput:un,LoadLatent:cn,LoadVideo:gn,LoraLoader:bn,LoraLoaderModelOnly:yn,LoraSave:fn,LotusConditioning:hn,LumaConceptsNode:zn,LumaImageModifyNode:vn,LumaImageNode:Sn,LumaImageToVideoNode:Ln,LumaReferenceNode:Cn,LumaVideoNode:Mn,Mahiro:Gn,MaskComposite:Vn,MaskPreview:In,MaskToImage:An,MinimaxImageToVideoNode:Pn,MinimaxTextToVideoNode:Dn,ModelComputeDtype:Kn,ModelMergeAdd:xn,ModelMergeAuraflow:Bn,ModelMergeBlocks:Tn,ModelMergeCosmos14B:En,ModelMergeCosmos7B:Nn,ModelMergeFlux1:Rn,ModelMergeLTXV:Fn,ModelMergeMochiPreview:Un,ModelMergeSD1:wn,ModelMergeSD2:On,ModelMergeSD35_Large:jn,ModelMergeSD3_2B:Hn,ModelMergeSDXL:Yn,ModelMergeSimple:Wn,ModelMergeSubtract:Xn,ModelMergeWAN2_1:Zn,ModelSamplingAuraFlow:qn,ModelSamplingContinuousEDM:Qn,ModelSamplingContinuousV:Jn,ModelSamplingDiscrete:$n,ModelSamplingFlux:ei,ModelSamplingLTXV:ai,ModelSamplingSD3:ni,ModelSamplingStableCascade:ii,ModelSave:li,Morphology:ti,OpenAIDalle2:oi,OpenAIDalle3:mi,OpenAIGPTImage1:ri,OptimalStepsScheduler:si,PairConditioningCombine:_i,PairConditioningSetDefaultCombine:ki,PairConditioningSetProperties:di,PairConditioningSetPropertiesAndCombine:pi,PatchModelAddDownscale:ui,PerpNeg:ci,PerpNegGuider:gi,PerturbedAttentionGuidance:bi,PhotoMakerEncode:yi,PhotoMakerLoader:fi,PikaImageToVideoNode2_2:hi,PikaScenesV2_2:zi,PikaStartEndFrameNode2_2:vi,PikaTextToVideoNode2_2:Si,Pikadditions:Li,Pikaffects:Ci,Pikaswaps:Mi,PixverseImageToVideoNode:Gi,PixverseTemplateNode:Vi,PixverseTextToVideoNode:Ii,PixverseTransitionVideoNode:Ai,PolyexponentialScheduler:Pi,PorterDuffImageComposite:Di,Preview3D:Ki,Preview3DAnimation:xi,PreviewAny:Bi,PreviewAudio:Ti,PreviewImage:Ei,PrimitiveBoolean:Ni,PrimitiveFloat:Ri,PrimitiveInt:Fi,PrimitiveString:Ui,PrimitiveStringMultiline:wi,QuadrupleCLIPLoader:Oi,RandomNoise:ji,RebatchImages:Hi,RebatchLatents:Yi,RecraftColorRGB:Wi,RecraftControls:Xi,RecraftCreativeUpscaleNode:Zi,RecraftCrispUpscaleNode:qi,RecraftImageInpaintingNode:Qi,RecraftImageToImageNode:Ji,RecraftRemoveBackgroundNode:$i,RecraftReplaceBackgroundNode:el,RecraftStyleV3DigitalIllustration:al,RecraftStyleV3InfiniteStyleLibrary:nl,RecraftStyleV3LogoRaster:il,RecraftStyleV3RealisticImage:ll,RecraftTextToImageNode:tl,RecraftTextToVectorNode:ol,RecraftVectorizeImageNode:ml,RenormCFG:rl,RepeatImageBatch:sl,RepeatLatentBatch:_l,RescaleCFG:kl,SDTurboScheduler:dl,SD_4XUpscale_Conditioning:pl,SV3D_Conditioning:ul,SVD_img2vid_Conditioning:cl,SamplerCustom:gl,SamplerCustomAdvanced:bl,SamplerDPMAdaptative:yl,SamplerDPMPP_2M_SDE:fl,SamplerDPMPP_2S_Ancestral:hl,SamplerDPMPP_3M_SDE:zl,SamplerDPMPP_SDE:vl,SamplerEulerAncestral:Sl,SamplerEulerAncestralCFGPP:Ll,SamplerEulerCFGpp:Cl,SamplerLCMUpscale:Ml,SamplerLMS:Gl,SaveAnimatedPNG:Vl,SaveAnimatedWEBP:Il,SaveAudio:Al,SaveGLB:Pl,SaveImage:Dl,SaveImageWebsocket:Kl,SaveLatent:xl,SaveVideo:Bl,SaveWEBM:Tl,SelfAttentionGuidance:El,SetClipHooks:Nl,SetFirstSigma:Rl,SetHookKeyframes:Fl,SetLatentNoiseMask:Ul,SetUnionControlNetType:wl,SkipLayerGuidanceDiT:Ol,SkipLayerGuidanceSD3:jl,SolidMask:Hl,SplitImageWithAlpha:Yl,SplitSigmas:Wl,SplitSigmasDenoise:Xl,StabilityStableImageSD_3_5Node:Zl,StabilityStableImageUltraNode:ql,StabilityUpscaleConservativeNode:Ql,StabilityUpscaleCreativeNode:Jl,StabilityUpscaleFastNode:$l,StableCascade_EmptyLatentImage:et,StableCascade_StageB_Conditioning:at,StableCascade_StageC_VAEEncode:nt,StableCascade_SuperResolutionControlnet:it,StableZero123_Conditioning:lt,StableZero123_Conditioning_Batched:tt,StyleModelApply:ot,StyleModelLoader:mt,T5TokenizerOptions:rt,TextEncodeHunyuanVideo_ImageToVideo:st,ThresholdMask:_t,TomePatchModel:kt,TorchCompileModel:dt,TrimVideoLatent:pt,TripleCLIPLoader:ut,UNETLoader:ct,UNetCrossAttentionMultiply:gt,UNetSelfAttentionMultiply:bt,UNetTemporalAttentionMultiply:yt,UpscaleModelLoader:ft,VAEDecode:ht,VAEDecodeAudio:zt,VAEDecodeHunyuan3D:vt,VAEDecodeTiled:St,VAEEncode:Lt,VAEEncodeAudio:Ct,VAEEncodeForInpaint:Mt,VAEEncodeTiled:Gt,VAELoader:Vt,VAESave:It,VPScheduler:At,VeoVideoGenerationNode:Pt,VideoLinearCFGGuidance:Dt,VideoTriangleCFGGuidance:Kt,VoxelToMesh:xt,VoxelToMeshBasic:Bt,WanFirstLastFrameToVideo:Tt,WanFunControlToVideo:Et,WanFunInpaintToVideo:Nt,WanImageToVideo:Rt,WanVaceToVideo:Ft,WebcamCapture:Ut,unCLIPCheckpointLoader:wt,unCLIPConditioning:Ot};export{e as AddNoise,a as AlignYourStepsScheduler,n as BasicGuider,i as BasicScheduler,l as BetaSamplingScheduler,t as CFGGuider,o as CFGZeroStar,m as CLIPAttentionMultiply,r as CLIPLoader,s as CLIPMergeAdd,_ as CLIPMergeSimple,k as CLIPMergeSubtract,d as CLIPSave,p as CLIPSetLastLayer,u as CLIPTextEncode,c as CLIPTextEncodeControlnet,g as CLIPTextEncodeFlux,b as CLIPTextEncodeHiDream,y as CLIPTextEncodeHunyuanDiT,f as CLIPTextEncodeLumina2,h as CLIPTextEncodePixArtAlpha,z as CLIPTextEncodeSD3,v as CLIPTextEncodeSDXL,S as CLIPTextEncodeSDXLRefiner,L as CLIPVisionEncode,C as CLIPVisionLoader,M as Canny,G as CheckpointLoader,V as CheckpointLoaderSimple,I as CheckpointSave,A as CombineHooks2,P as CombineHooks4,D as CombineHooks8,K as ConditioningAverage,x as ConditioningCombine,B as ConditioningConcat,T as ConditioningSetArea,E as ConditioningSetAreaPercentage,N as ConditioningSetAreaPercentageVideo,R as ConditioningSetAreaStrength,F as ConditioningSetDefaultCombine,U as ConditioningSetMask,w as ConditioningSetProperties,O as ConditioningSetPropertiesAndCombine,j as ConditioningSetTimestepRange,H as ConditioningStableAudio,Y as ConditioningTimestepsRange,W as ConditioningZeroOut,X as ControlNetApply,Z as ControlNetApplyAdvanced,q as ControlNetApplySD3,Q as ControlNetInpaintingAliMamaApply,J as ControlNetLoader,$ as CosmosImageToVideoLatent,ee as CreateHookKeyframe,ae as CreateHookKeyframesFromFloats,ne as CreateHookKeyframesInterpolated,ie as CreateHookLora,le as CreateHookLoraModelOnly,te as CreateHookModelAsLora,oe as CreateHookModelAsLoraModelOnly,me as CreateVideo,re as CropMask,se as DiffControlNetLoader,_e as DifferentialDiffusion,ke as DiffusersLoader,de as DisableNoise,pe as DualCFGGuider,ue as DualCLIPLoader,ce as EmptyCosmosLatentVideo,ge as EmptyHunyuanLatentVideo,be as EmptyImage,ye as EmptyLTXVLatentVideo,fe as EmptyLatentAudio,he as EmptyLatentHunyuan3Dv2,ze as EmptyLatentImage,ve as EmptyMochiLatentVideo,Se as EmptySD3LatentImage,Le as ExponentialScheduler,Ce as ExtendIntermediateSigmas,Me as FeatherMask,Ge as FlipSigmas,Ve as FluxDisableGuidance,Ie as FluxGuidance,Ae as FluxProExpandNode,Pe as FluxProFillNode,De as FluxProUltraImageNode,Ke as FreSca,xe as FreeU,Be as FreeU_V2,Te as GITSScheduler,Ee as GLIGENLoader,Ne as GLIGENTextBoxApply,Re as GetVideoComponents,Fe as GrowMask,Ue as Hunyuan3Dv2Conditioning,we as Hunyuan3Dv2ConditioningMultiView,Oe as HunyuanImageToVideo,je as HyperTile,He as HypernetworkLoader,Ye as IdeogramV1,We as IdeogramV2,Xe as IdeogramV3,Ze as ImageBatch,qe as ImageBlend,Qe as ImageBlur,Je as ImageColorToMask,$e as ImageCompositeMasked,ea as ImageCrop,aa as ImageFromBatch,na as ImageInvert,ia as ImageOnlyCheckpointLoader,la as ImageOnlyCheckpointSave,ta as ImagePadForOutpaint,oa as ImageQuantize,ma as ImageRGBToYUV,ra as ImageScale,sa as ImageScaleBy,_a as ImageScaleToTotalPixels,ka as ImageSharpen,da as ImageToMask,pa as ImageUpscaleWithModel,ua as ImageYUVToRGB,ca as InpaintModelConditioning,ga as InstructPixToPixConditioning,ba as InvertMask,ya as JoinImageWithAlpha,fa as KSampler,ha as KSamplerAdvanced,za as KSamplerSelect,va as KarrasScheduler,Sa as KlingCameraControlI2VNode,La as KlingCameraControlT2VNode,Ca as KlingCameraControls,Ma as KlingDualCharacterVideoEffectNode,Ga as KlingImage2VideoNode,Va as KlingImageGenerationNode,Ia as KlingLipSyncAudioToVideoNode,Aa as KlingLipSyncTextToVideoNode,Pa as KlingSingleImageVideoEffectNode,Da as KlingStartEndFrameNode,Ka as KlingTextToVideoNode,xa as KlingVideoExtendNode,Ba as KlingVirtualTryOnNode,Ta as LTXVAddGuide,Ea as LTXVConditioning,Na as LTXVCropGuides,Ra as LTXVImgToVideo,Fa as LTXVPreprocess,Ua as LTXVScheduler,wa as LaplaceScheduler,Oa as LatentAdd,ja as LatentApplyOperation,Ha as LatentApplyOperationCFG,Ya as LatentBatch,Wa as LatentBatchSeedBehavior,Xa as LatentBlend,Za as LatentComposite,qa as LatentCompositeMasked,Qa as LatentCrop,Ja as LatentFlip,$a as LatentFromBatch,en as LatentInterpolate,an as LatentMultiply,nn as LatentOperationSharpen,ln as LatentOperationTonemapReinhard,tn as LatentRotate,on as LatentSubtract,mn as LatentUpscale,rn as LatentUpscaleBy,sn as Load3D,_n as Load3DAnimation,kn as LoadAudio,dn as LoadImage,pn as LoadImageMask,un as LoadImageOutput,cn as LoadLatent,gn as LoadVideo,bn as LoraLoader,yn as LoraLoaderModelOnly,fn as LoraSave,hn as LotusConditioning,zn as LumaConceptsNode,vn as LumaImageModifyNode,Sn as LumaImageNode,Ln as LumaImageToVideoNode,Cn as LumaReferenceNode,Mn as LumaVideoNode,Gn as Mahiro,Vn as MaskComposite,In as MaskPreview,An as MaskToImage,Pn as MinimaxImageToVideoNode,Dn as MinimaxTextToVideoNode,Kn as ModelComputeDtype,xn as ModelMergeAdd,Bn as ModelMergeAuraflow,Tn as ModelMergeBlocks,En as ModelMergeCosmos14B,Nn as ModelMergeCosmos7B,Rn as ModelMergeFlux1,Fn as ModelMergeLTXV,Un as ModelMergeMochiPreview,wn as ModelMergeSD1,On as ModelMergeSD2,jn as ModelMergeSD35_Large,Hn as ModelMergeSD3_2B,Yn as ModelMergeSDXL,Wn as ModelMergeSimple,Xn as ModelMergeSubtract,Zn as ModelMergeWAN2_1,qn as ModelSamplingAuraFlow,Qn as ModelSamplingContinuousEDM,Jn as ModelSamplingContinuousV,$n as ModelSamplingDiscrete,ei as ModelSamplingFlux,ai as ModelSamplingLTXV,ni as ModelSamplingSD3,ii as ModelSamplingStableCascade,li as ModelSave,ti as Morphology,oi as OpenAIDalle2,mi as OpenAIDalle3,ri as OpenAIGPTImage1,si as OptimalStepsScheduler,_i as PairConditioningCombine,ki as PairConditioningSetDefaultCombine,di as PairConditioningSetProperties,pi as PairConditioningSetPropertiesAndCombine,ui as PatchModelAddDownscale,ci as PerpNeg,gi as PerpNegGuider,bi as PerturbedAttentionGuidance,yi as PhotoMakerEncode,fi as PhotoMakerLoader,hi as PikaImageToVideoNode2_2,zi as PikaScenesV2_2,vi as PikaStartEndFrameNode2_2,Si as PikaTextToVideoNode2_2,Li as Pikadditions,Ci as Pikaffects,Mi as Pikaswaps,Gi as PixverseImageToVideoNode,Vi as PixverseTemplateNode,Ii as PixverseTextToVideoNode,Ai as PixverseTransitionVideoNode,Pi as PolyexponentialScheduler,Di as PorterDuffImageComposite,Ki as Preview3D,xi as Preview3DAnimation,Bi as PreviewAny,Ti as PreviewAudio,Ei as PreviewImage,Ni as PrimitiveBoolean,Ri as PrimitiveFloat,Fi as PrimitiveInt,Ui as PrimitiveString,wi as PrimitiveStringMultiline,Oi as QuadrupleCLIPLoader,ji as RandomNoise,Hi as RebatchImages,Yi as RebatchLatents,Wi as RecraftColorRGB,Xi as RecraftControls,Zi as RecraftCreativeUpscaleNode,qi as RecraftCrispUpscaleNode,Qi as RecraftImageInpaintingNode,Ji as RecraftImageToImageNode,$i as RecraftRemoveBackgroundNode,el as RecraftReplaceBackgroundNode,al as RecraftStyleV3DigitalIllustration,nl as RecraftStyleV3InfiniteStyleLibrary,il as RecraftStyleV3LogoRaster,ll as RecraftStyleV3RealisticImage,tl as RecraftTextToImageNode,ol as RecraftTextToVectorNode,ml as RecraftVectorizeImageNode,rl as RenormCFG,sl as RepeatImageBatch,_l as RepeatLatentBatch,kl as RescaleCFG,dl as SDTurboScheduler,pl as SD_4XUpscale_Conditioning,ul as SV3D_Conditioning,cl as SVD_img2vid_Conditioning,gl as SamplerCustom,bl as SamplerCustomAdvanced,yl as SamplerDPMAdaptative,fl as SamplerDPMPP_2M_SDE,hl as SamplerDPMPP_2S_Ancestral,zl as SamplerDPMPP_3M_SDE,vl as SamplerDPMPP_SDE,Sl as SamplerEulerAncestral,Ll as SamplerEulerAncestralCFGPP,Cl as SamplerEulerCFGpp,Ml as SamplerLCMUpscale,Gl as SamplerLMS,Vl as SaveAnimatedPNG,Il as SaveAnimatedWEBP,Al as SaveAudio,Pl as SaveGLB,Dl as SaveImage,Kl as SaveImageWebsocket,xl as SaveLatent,Bl as SaveVideo,Tl as SaveWEBM,El as SelfAttentionGuidance,Nl as SetClipHooks,Rl as SetFirstSigma,Fl as SetHookKeyframes,Ul as SetLatentNoiseMask,wl as SetUnionControlNetType,Ol as SkipLayerGuidanceDiT,jl as SkipLayerGuidanceSD3,Hl as SolidMask,Yl as SplitImageWithAlpha,Wl as SplitSigmas,Xl as SplitSigmasDenoise,Zl as StabilityStableImageSD_3_5Node,ql as StabilityStableImageUltraNode,Ql as StabilityUpscaleConservativeNode,Jl as StabilityUpscaleCreativeNode,$l as StabilityUpscaleFastNode,et as StableCascade_EmptyLatentImage,at as StableCascade_StageB_Conditioning,nt as StableCascade_StageC_VAEEncode,it as StableCascade_SuperResolutionControlnet,lt as StableZero123_Conditioning,tt as StableZero123_Conditioning_Batched,ot as StyleModelApply,mt as StyleModelLoader,rt as T5TokenizerOptions,st as TextEncodeHunyuanVideo_ImageToVideo,_t as ThresholdMask,kt as TomePatchModel,dt as TorchCompileModel,pt as TrimVideoLatent,ut as TripleCLIPLoader,ct as UNETLoader,gt as UNetCrossAttentionMultiply,bt as UNetSelfAttentionMultiply,yt as UNetTemporalAttentionMultiply,ft as UpscaleModelLoader,ht as VAEDecode,zt as VAEDecodeAudio,vt as VAEDecodeHunyuan3D,St as VAEDecodeTiled,Lt as VAEEncode,Ct as VAEEncodeAudio,Mt as VAEEncodeForInpaint,Gt as VAEEncodeTiled,Vt as VAELoader,It as VAESave,At as VPScheduler,Pt as VeoVideoGenerationNode,Dt as VideoLinearCFGGuidance,Kt as VideoTriangleCFGGuidance,xt as VoxelToMesh,Bt as VoxelToMeshBasic,Tt as WanFirstLastFrameToVideo,Et as WanFunControlToVideo,Nt as WanFunInpaintToVideo,Rt as WanImageToVideo,Ft as WanVaceToVideo,Ut as WebcamCapture,jt as default,wt as unCLIPCheckpointLoader,Ot as unCLIPConditioning};
//# sourceMappingURL=nodeDefs-CVoiPJT3.js.map
